import { exceptionalError } from '../salesforce.js';
import { logger } from '../salesforce.js';
import util from 'util';
export class generalObject {
    constructor(dataStructure, apiMapping) {
        this.details = {};
        this.apiMapping = {};
        this.dataStructure = {};
        this.loadedFromSF = false;
        this.idReferenceName = null;
        this.apiMapping = apiMapping;
        this.dataStructure = dataStructure;
        this.loadFromSF({});
    }
    loadFromSF(sfObj) {
        //@ts-ignore
        this.details = this.createNiceObj(sfObj, this.dataStructure, this.apiMapping);
        //@ts-ignore yargh
        if (this.details.id) {
            this.loadedFromSF = true;
        }
    }
    createSF(update = false) {
        if (!update) {
            this.checkMandatoryFields(update);
        }
        return this.createSFObject(this.details, this.dataStructure, this.apiMapping, update);
    }
    checkMandatoryFields(update = false) {
        let mandatory = {};
        for (const [level, levelKeys] of Object.entries(this.dataStructure)) {
            for (const [levelKey, levelDetails] of Object.entries(levelKeys)) {
                if (levelDetails.mandatory) {
                    if (!mandatory.hasOwnProperty(level)) {
                        mandatory[level] = [];
                    }
                    mandatory[level].push(levelKey);
                }
            }
        }
        for (const [mandatoryLevel, mandatoryKeys] of Object.entries(mandatory)) {
            let checkLevel = null;
            if (mandatoryLevel === 'topLevel') {
                checkLevel = this.details;
            }
            else {
                if (!this.details.hasOwnProperty(mandatoryLevel)) {
                    throw new exceptionalError(`Missing mandatory level ${mandatoryLevel} from input`);
                }
                //@ts-ignore
                checkLevel = this.details[mandatoryLevel];
            }
            for (const reqKey of mandatoryKeys) {
                if (!checkLevel.hasOwnProperty(reqKey) || checkLevel[reqKey] === undefined || checkLevel[reqKey] === null) {
                    throw new exceptionalError(`Missing mandatory value ${mandatoryLevel} -> ${reqKey} from input`);
                }
            }
        }
    }
    createNiceObj(sourceObject, tgtObjectStructure, apiMapping) {
        let returnObj = {};
        for (const [key, dataPoints] of Object.entries(tgtObjectStructure)) {
            if (key === 'topLevel') {
                returnObj = this.addFieldsToNiceObject(sourceObject, dataPoints, apiMapping);
            }
            else {
                //@ts-ignore get outta here
                returnObj[key] = this.addFieldsToNiceObject(sourceObject, dataPoints, apiMapping);
            }
        }
        return returnObj;
    }
    addFieldsToNiceObject(sourceObj, dataPoints, apiMapping) {
        let retObj = {};
        for (const [niceName, details] of Object.entries(dataPoints)) {
            if (!apiMapping.hasOwnProperty(niceName)) {
                throw new exceptionalError(`Unknown nice name ${niceName}`);
            }
            let targetVal = null;
            if (sourceObj.hasOwnProperty(apiMapping[niceName])) {
                targetVal = sourceObj[apiMapping[niceName]];
            }
            //@ts-ignore - remove this!
            if (targetVal && details.type.includes("date") && targetVal.match(/\d{4}-\d{2}-\d{2}/)) {
                targetVal = new Date(targetVal);
            }
            retObj[niceName] = targetVal;
        }
        return retObj;
    }
    createSFObject(srcObject, srcStructure, apiMapping, update) {
        let sfObject = {};
        for (const [keyName, topVal] of Object.entries(srcObject)) {
            if (topVal !== null && typeof (topVal) === 'object') {
                for (const [subKey, subVal] of Object.entries(topVal)) {
                    sfObject = this.addFieldsToSFObject(sfObject, subKey, subVal, keyName, srcStructure, apiMapping, update);
                }
            }
            else {
                sfObject = this.addFieldsToSFObject(sfObject, keyName, topVal, null, srcStructure, apiMapping, update);
            }
        }
        return sfObject;
    }
    addFieldsToSFObject(sfObject, key, val, levelUp, srcStructure, apiMapping, update) {
        var _a;
        if (!apiMapping.hasOwnProperty(key)) {
            throw new exceptionalError(`Unknown niceName \"${key}\" for object`);
        }
        let parent;
        if (!levelUp) {
            levelUp = 'topLevel';
        }
        if (!srcStructure.hasOwnProperty(levelUp)) {
            throw new exceptionalError(`Level ${levelUp} is not defined for object`);
        }
        if (!srcStructure[levelUp].hasOwnProperty(key)) {
            throw new exceptionalError(`Key "${key}" is not defined for object at level "${levelUp}"`);
        }
        if (srcStructure[levelUp][key].readOnly || (!srcStructure[levelUp][key].updateable && update)) {
            return sfObject;
        }
        let valType = typeof (val);
        let expectedTypes = srcStructure[levelUp][key].type;
        if (valType === 'object') {
            switch (true) {
                case Date.prototype.isPrototypeOf(val):
                    valType = 'date';
                    val = val.toISOString();
                    break;
                case (val === null):
                    valType = null;
                    break;
                default:
                    logger.info(util.inspect(val));
                    throw new exceptionalError(`Can't use an object as a value when creating an SF obj`);
            }
        }
        if (!expectedTypes.includes(valType)) {
            throw new exceptionalError(`Field ${key} was type \"${valType}\" but must be ${expectedTypes.map((s) => (String(s))).join(" or ")}`);
        }
        if (srcStructure[levelUp][key].validation) {
            if (!((_a = srcStructure[levelUp][key].validation) === null || _a === void 0 ? void 0 : _a.includes(val))) {
                throw new exceptionalError(`Field \"${key}\" (${val}) is value restricted and must be one of ${srcStructure[levelUp][key].validation.join(" or ")}`);
            }
        }
        sfObject[apiMapping[key]] = val;
        return sfObject;
    }
    validateGetChild(filters) {
        if (!filters) {
            filters = {};
        }
        //@ts-ignore MEH
        if (this.loadedFromSF && this.details.id && this.idReferenceName) {
            // SF has the two ID formats, 15 and 18 characters which is very annoying - so cover both
            // e.g. accountID__c = 'a0gJA0000000dLuYAI' OR accountID__c = 'a0gJA0000000dLu'
            //@ts-ignore I could fix this right now
            if (this.details.id.length > 15) {
                //@ts-ignore but I'm out of time
                filters[this.idReferenceName] = [this.details.id, this.details.id.replace(/.{3}$/, "")];
            }
            else {
                //@ts-ignore STOP LOOKING AT THIS
                filters[this.idReferenceName] = this.details.id;
            }
            return filters;
        }
        logger.info(util.inspect(filters));
        logger.info(util.inspect(this.details));
        throw new exceptionalError(`Can only get children for objects loaded from SF with a valid ID set`);
    }
    validateCreateChild(createChildFunction, parentIdName) {
        //@ts-ignore MEH
        if (this.loadedFromSF && this.details.id) {
            let newChild = createChildFunction();
            //@ts-ignore
            newChild.details[parentIdName] = this.details.id;
            return newChild;
        }
        logger.info(`parentIdName: ${parentIdName}`);
        logger.info(`LoadedFromSF: ${this.loadedFromSF}`);
        logger.info(util.inspect(this.details));
        throw new exceptionalError(`Can only create children for objects loaded from SF with a valid ID set`);
    }
}
