var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import * as genericObject from './baseSFObjClass.js';
import { exceptionalError } from '../salesforce.js';
import * as sfMethods from '../salesforce.js';
import * as returnObject from './return.js';
import * as orderObject from './order.js';
import * as objConstants from './constants/location.constants.js';
export { objConstants };
class Location extends genericObject.generalObject {
    constructor() {
        super(objConstants.dataStructure, objConstants.apiMapping);
        this.details = this.createNiceObj({}, objConstants.dataStructure, objConstants.apiMapping);
        this.type = 'location';
        this.writeable = true;
        this.idReferenceName = "locationId";
    }
    createSF(update = false) {
        let returnSFObj = super.createSF(update);
        const provMapping = objConstants.apiMapping.province;
        const postalCodeMapping = objConstants.apiMapping.postalCode;
        const countryMapping = objConstants.apiMapping.country;
        const cityMapping = objConstants.apiMapping.city;
        // Province/state value needs to match dropdown boxes in SF
        if (returnSFObj[provMapping]) {
            //@ts-ignore yes I know you hate this :mad:
            const newProv = objConstants.provinceMapping[returnSFObj[provMapping]];
            if (!newProv) {
                throw new exceptionalError(`Invalid province/state value ${returnSFObj[provMapping]}`);
            }
            returnSFObj[provMapping] = newProv;
        }
        // Canadian postal codes need the space
        if (returnSFObj[postalCodeMapping] && returnSFObj[countryMapping] && returnSFObj[countryMapping].match(/^ca$/i)) {
            const newPostal = returnSFObj[postalCodeMapping].replace(/\W/, "").match(/.{3}/g).join(" ");
            returnSFObj[postalCodeMapping] = newPostal;
            this.details.address.postalCode = newPostal;
        }
        // Remove any saucy characters from city names
        if (returnSFObj[cityMapping]) {
            const newCity = returnSFObj[cityMapping].replace(/[^\w ]/g, '');
            returnSFObj[cityMapping] = newCity;
            this.details.address.city = newCity;
        }
        return returnSFObj;
    }
    loadFromSF(sfObj) {
        super.loadFromSF(sfObj);
        if (this.details.address.province && this.details.address.province.length > 2) {
            this.details.address.province = this.details.address.province.substring(0, 2);
        }
    }
    getOrders(filters, orderStatus = null) {
        return __awaiter(this, void 0, void 0, function* () {
            filters = this.validateGetChild(filters);
            if (orderStatus) {
                return yield sfMethods.getBD2OrdersByStatus(orderStatus, filters);
            }
            else {
                return yield sfMethods.getBD2Orders(filters);
            }
        });
    }
    getReturns(filters) {
        return __awaiter(this, void 0, void 0, function* () {
            filters = this.validateGetChild(filters);
            return yield sfMethods.getBD2Returns(filters);
        });
    }
    createOrder(qty = null) {
        let newOrder = this.validateCreateChild(orderObject.createNew, "locationId");
        newOrder.details.orderDetails.bd2Model = orderObject.objConstants.bd2ModelClassic;
        if (this.details.address.country === objConstants.countryCanada) {
            newOrder.details.money.moneyCurrency = orderObject.objConstants.moneyCurrencyCAD;
        }
        else {
            newOrder.details.money.moneyCurrency = orderObject.objConstants.moneyCurrencyUSD;
        }
        if (qty) {
            newOrder.details.fulfillment.qtyRequested = qty;
        }
        newOrder.details.fulfillment.shippingService = orderObject.objConstants.shipServiceStandard;
        newOrder.details.accountId = this.details.accountId;
        return newOrder;
    }
    createReturn() {
        return this.validateCreateChild(returnObject.createNew, "locationId");
    }
}
export function createNew() {
    return new Location();
}
