var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import chai from 'chai';
import chaiAsPromised from "chai-as-promised";
import fetchMock from 'fetch-mock';
import * as testAccountCases from './testDetails/salesforce.cases.accounts.js';
import * as testAuthCases from './testDetails/salesforce.cases.auth.js';
import * as testLocationCases from './testDetails/salesforce.cases.locations.js';
import * as SalesForcer from '../salesforce.js';
import * as SfAPI from '../salesforceAPI.js';
const expect = chai.expect;
chai.use(chaiAsPromised);
// No create or update account methods - should only be created manually in SF
// If unknown accounts are issues when syncing from shopify we'll post a slack notification
describe('Test the SalesForcer Account Level Functions', () => __awaiter(void 0, void 0, void 0, function* () {
    before(() => __awaiter(void 0, void 0, void 0, function* () {
        SfAPI.disconnect();
        fetchMock.restore();
        let authMock = testAuthCases.apiMockCases.goodTokenReq;
        fetchMock.post(authMock.req.url, { status: authMock.req.code, body: authMock.req.body });
        yield SfAPI.connect();
        fetchMock.restore();
    }));
    context('Test account search functions', () => __awaiter(void 0, void 0, void 0, function* () {
        before(() => __awaiter(void 0, void 0, void 0, function* () {
            fetchMock.restore();
            fetchMock.get(testAccountCases.getAccountNoMatch.req.url, testAccountCases.getAccountNoMatch.req.body);
            fetchMock.get(testAccountCases.accountByNameOrIDWithLocations.req.url, testAccountCases.accountByNameOrIDWithLocations.req.body);
            fetchMock.get(testAccountCases.accountWithoutLocations.req.url, testAccountCases.accountWithoutLocations.req.body);
            fetchMock.get(testLocationCases.locationThatExists.req.url, testLocationCases.locationThatExists.req.body);
        }));
        it('Throws errors for invalid account fields', () => __awaiter(void 0, void 0, void 0, function* () {
            //@ts-ignore
            yield expect(SalesForcer.getBD2Accounts({ yert: "lol" })).to.be.rejectedWith('Unsupported filter yert for query type BD2_Account__c');
        }));
        it('Handles the no-match state by returning null', () => __awaiter(void 0, void 0, void 0, function* () {
            let noMatch = yield SalesForcer.getBD2Accounts({ accountName: "Bob Of Mainframe" });
            expect(noMatch).to.be.empty;
        }));
        it('Gets account by name', () => __awaiter(void 0, void 0, void 0, function* () {
            let accountByName = yield SalesForcer.getBD2Accounts({ accountName: "ACME" });
            expect(accountByName[0].details).to.deep.equal(testAccountCases.accountByNameOrIDWithLocations.resp);
        }));
        it('Get account by ID', () => __awaiter(void 0, void 0, void 0, function* () {
            let accountByName = yield SalesForcer.getBD2Accounts({ id: "someRandomIdLookATthis0mg" });
            expect(accountByName[0].details).to.deep.equal(testAccountCases.accountByNameOrIDWithLocations.resp);
        }));
    }));
}));
