var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import chai from 'chai';
import chaiAsPromised from "chai-as-promised";
import fetchMock from 'fetch-mock';
import * as testCases from './testDetails/salesforce.cases.functional.js';
import * as testAuthCases from './testDetails/salesforce.cases.auth.js';
import * as functionalAddresses from './testDetails/salesforce.cases.functional.locations.js';
import * as SalesForcer from '../salesforce.js';
import * as SfAPI from '../salesforceAPI.js';
import * as orderObject from '../sfObjects/order.js';
import * as locationObj from '../sfObjects/location.js';
// TO TEST IN SHOPIFY SCRIPT
// 1) Override dealer ID, name, email
// 2) Shipping notification emails
// 3) Shipping address w/ override
// 4) SKU bundling
// FUTURE
// Scanner tracking??
const expect = chai.expect;
chai.use(chaiAsPromised);
describe('Test the nice pre-canned tasty functions', () => __awaiter(void 0, void 0, void 0, function* () {
    before(() => __awaiter(void 0, void 0, void 0, function* () {
        SfAPI.disconnect();
        fetchMock.restore();
        let authMock = testAuthCases.apiMockCases.goodTokenReq;
        fetchMock.post(authMock.req.url, { status: authMock.req.code, body: authMock.req.body });
        fetchMock.get('lol', 200);
        yield SfAPI.connect();
        fetchMock.restore();
    }));
    context('Creating locations with match check', () => __awaiter(void 0, void 0, void 0, function* () {
        for (const test of functionalAddresses.duplicateLocationTests) {
            it(test.testing, () => __awaiter(void 0, void 0, void 0, function* () {
                fetchMock.restore();
                fetchMock.get(new RegExp(test.matchURL), test.returnBody);
                fetchMock.post(/./i, (url, opts) => __awaiter(void 0, void 0, void 0, function* () {
                    return testCases.checkWriteBody(url, opts);
                }));
                let newLocation = locationObj.createNew();
                newLocation.details.address.streetAddress = test.requestDeets.streetAddress;
                newLocation.details.address.city = test.requestDeets.city;
                newLocation.details.address.province = test.requestDeets.province;
                newLocation.details.address.postalCode = test.requestDeets.postalCode;
                newLocation.details.address.country = test.requestDeets.country;
                newLocation.details.accountId = test.requestDeets.accountId;
                newLocation.details.locationName = "Blah blah blah";
                if (test.expectedValue === null) {
                    newLocation.details.locationName = "Name";
                }
                let response = yield SalesForcer.createOrFindLocation(newLocation);
                expect(response.details).to.deep.equal(test.expectedValue);
            }));
        }
    }));
    context('Updating location if new details are provided', () => __awaiter(void 0, void 0, void 0, function* () {
        before(() => __awaiter(void 0, void 0, void 0, function* () {
            fetchMock.restore();
            fetchMock.post(/./i, (url, opts) => __awaiter(void 0, void 0, void 0, function* () {
                return testCases.checkWriteBody(url, opts);
            }));
            fetchMock.patch(/./i, (url, opts) => __awaiter(void 0, void 0, void 0, function* () {
                return testCases.checkWriteBody(url, opts);
            }));
            fetchMock.get(new RegExp(testCases.accountMatchWithNameSet.matchURL), testCases.accountMatchWithNameSet.returnBody);
            fetchMock.get(new RegExp(testCases.accountMatchWithoutDealerId.matchURL), testCases.accountMatchWithoutDealerId.returnBody);
        }));
        let newLocationDetails = {
            id: null,
            locationName: "Testing updating null fields",
            businessName: "Some Business Without DealerID",
            accountId: "Some Business Without DealerID",
            email: "thing@sympatico.nf.ca",
            phone: null,
            dealerId: "theDealerId",
            address: {
                receiverName: "Person Q",
                streetAddress: "123 Street Street",
                city: "Glovertown",
                province: "KS",
                postalCode: "88432-1234",
                country: "US",
                fullAddress: null
            }
        };
        it('Adds dealerID if previously absent', () => __awaiter(void 0, void 0, void 0, function* () {
            let newLocation = locationObj.createNew();
            newLocation.loadedFromSF = true;
            //@ts-ignore
            newLocation.details = newLocationDetails;
            let update = yield SalesForcer.createOrFindLocation(newLocation);
            //@ts-ignore
            expect(update.details.id).to.equal("locationBeingTestedForUpdating");
        }));
        it('Doesnt change business name if already set but different', () => __awaiter(void 0, void 0, void 0, function* () {
            let newLocation = locationObj.createNew();
            newLocation.loadedFromSF = true;
            //@ts-ignore
            newLocation.details = newLocationDetails;
            newLocation.details.businessName = "This Should Fail - Name Already Set";
            newLocation.details.accountId = "This Should Fail - Name Already Set";
            let sameObj = yield SalesForcer.createOrFindLocation(newLocation);
            newLocation.details.id = "locationBeingTestedForUpdating";
            expect(sameObj).to.deep.equal(newLocation);
        }));
    }));
    context('Creating orders from bulk stock', () => __awaiter(void 0, void 0, void 0, function* () {
        before(() => __awaiter(void 0, void 0, void 0, function* () {
            fetchMock.restore();
            fetchMock.post(/./i, (url, opts) => __awaiter(void 0, void 0, void 0, function* () {
                return testCases.checkWriteBody(url, opts);
            }));
            fetchMock.patch(/./i, (url, opts) => __awaiter(void 0, void 0, void 0, function* () {
                return testCases.checkWriteBody(url, opts);
            }));
            fetchMock.get(testCases.accountWithNoSKUs.url, testCases.accountWithNoSKUs.body);
            fetchMock.get(testCases.accountWithFallbackPermitted.url, testCases.accountWithFallbackPermitted.body);
            fetchMock.get(testCases.inventoryMatchesAndPermitsNew.url, testCases.inventoryMatchesAndPermitsNew.body);
            fetchMock.get(testCases.inventoryMatchesInsufficientQty.url, testCases.inventoryMatchesInsufficientQty.body);
            fetchMock.get(testCases.fallBackInventoryNoMatch.url, testCases.fallBackInventoryNoMatch.body);
            fetchMock.get(testCases.accountWithFallbackDisabled.url, testCases.accountWithFallbackDisabled.body);
            fetchMock.get(testCases.inventoryReplacementOnly.url, testCases.inventoryReplacementOnly.body);
            fetchMock.get(testCases.fallBackInventoryWithMatchWithoutExtSKU.url, testCases.fallBackInventoryWithMatchWithoutExtSKU.body);
            fetchMock.get(testCases.fallBackInventoryReplacementNoMatch.url, testCases.fallBackInventoryReplacementNoMatch.body);
        }));
        it('Throws an exception trying to create orders with invalid types, sources, or shipping', () => __awaiter(void 0, void 0, void 0, function* () {
            //@ts-ignore
            expect(SalesForcer.createNewOrder(null, "abc123", null, null)).to.be.rejectedWith(`Invalid order type "abc123"`);
            //@ts-ignore
            expect(SalesForcer.createNewOrder(null, "new", "321cba", null)).to.be.rejectedWith(`Invalid inventory source "321cba"`);
            //@ts-ignore
            expect(SalesForcer.createNewOrder(null, "new", "default", "qqqq")).to.be.rejectedWith(`Invalid shipping service "qqqq"`);
        }));
        it('Creates a new order from bulk placed through shopify', () => __awaiter(void 0, void 0, void 0, function* () {
            let newOrderObj = orderObject.createNew();
            newOrderObj.details.locationId = "someLocation";
            newOrderObj.details.accountId = "accountWithFallbackPermitted";
            newOrderObj.details.externalOrderNumber = "bulkShopifyOrder";
            newOrderObj.details.orderDetails.bd2Model = "Standard";
            newOrderObj.details.fulfillment.qtyRequested = 5;
            newOrderObj.details.money.moneyCurrency = "USD";
            newOrderObj.details.fulfillment.inventoryId = "inventoryWithPermittedNewAndQtyAvail";
            let newOrder = yield SalesForcer.createNewOrder(newOrderObj, "new", "bulk", "Local FedEx", true);
            expect(newOrder.details.orderDetails.orderType).to.equal("Order - From Bulk");
            expect(newOrder.details.id).to.equal("shopifyBulkedOrder");
            expect(newOrder.details.invoicing.invoiceStatus).to.equal("NA");
        }));
        it('Creates a new order from bulk stock - exists, permitted, and sufficient - Local shipping specified but external SKU overrides', () => __awaiter(void 0, void 0, void 0, function* () {
            let newOrderObj = orderObject.createNew();
            newOrderObj.details.locationId = "locationOne";
            newOrderObj.details.accountId = "anAccountWithNoSkus";
            newOrderObj.details.externalOrderNumber = "aSuccessfulNewBulkOrder1";
            newOrderObj.details.orderDetails.bd2Model = "Standard";
            newOrderObj.details.fulfillment.qtyRequested = 5;
            newOrderObj.details.money.moneyCurrency = "USD";
            newOrderObj.details.fulfillment.inventoryId = "inventoryWithPermittedNewAndQtyAvail";
            let newOrder = yield SalesForcer.createNewOrder(newOrderObj, "new", "bulk", "Local FedEx");
            expect(newOrder.details.id).to.equal("aNewBulkOrder1Created");
            //@ts-ignore
            expect(newOrder.details.fulfillment.inventoryId).to.equal("inventoryWithPermittedNewAndQtyAvail");
        }));
        it('Creates a new order from bulk stock - specified, exists, permitted, insufficient - falls back to RSL', () => __awaiter(void 0, void 0, void 0, function* () {
            let newOrderObj = orderObject.createNew();
            newOrderObj.details.locationId = "locationTwo";
            newOrderObj.details.externalOrderNumber = "aNewBulkFallbackOrder";
            newOrderObj.details.orderDetails.bd2Model = "Standard";
            newOrderObj.details.fulfillment.qtyRequested = 5;
            newOrderObj.details.money.moneyCurrency = "USD";
            newOrderObj.details.accountId = "accountWithFallbackPermitted";
            newOrderObj.details.fulfillment.inventoryId = "inventoryMatchesInsufficientQty";
            //@ts-ignore
            let newOrder = yield SalesForcer.createNewOrder(newOrderObj, "new", "bulk", "Local FedEx");
            expect(newOrder.details.id).to.equal("aNewBulkOrder2Created");
            expect(newOrder.details.fulfillment.shippingService).to.equal("Standard");
            expect(newOrder.details.fulfillment.inventoryId).to.be.null;
            expect(newOrder.details.orderDetails.orderType).to.equal("Order - Invoiced");
            expect(newOrder.details.notes).to.equal("Order specified bulk inventory inventoryMatchesInsufficientQty which was not available or valid");
        }));
        it('Creates a new order from bulk stock - specified, exists, permitted, insufficient - fallback denied, throw exception', () => __awaiter(void 0, void 0, void 0, function* () {
            let newOrderObj = orderObject.createNew();
            newOrderObj.details.locationId = "locationTwo";
            newOrderObj.details.externalOrderNumber = "aNewBulkFallbackOrder";
            newOrderObj.details.orderDetails.bd2Model = "Standard";
            newOrderObj.details.fulfillment.qtyRequested = 5;
            newOrderObj.details.money.moneyCurrency = "USD";
            newOrderObj.details.fulfillment.inventoryId = "inventoryMatchesInsufficientQty";
            newOrderObj.details.accountId = "accountWithFallbackDisabled";
            yield expect(SalesForcer.createNewOrder(newOrderObj, "new", "bulk", "Local FedEx")).to.be.rejectedWith("Unable to assign inventory for order aNewBulkFallbackOrder - order was not created");
        }));
        it('Creates a new order form bulk stock - exists and sufficient but not only permits replacements - fall back to another inventory that does', () => __awaiter(void 0, void 0, void 0, function* () {
            let newOrderObj = orderObject.createNew();
            newOrderObj.details.locationId = "locationThree";
            newOrderObj.details.externalOrderNumber = "aFallbackOrderDueToPermissionRestrictions";
            newOrderObj.details.orderDetails.bd2Model = "Standard";
            newOrderObj.details.fulfillment.qtyRequested = 25;
            newOrderObj.details.money.moneyCurrency = "USD";
            newOrderObj.details.fulfillment.inventoryId = "inventoryReplacementOnly";
            newOrderObj.details.accountId = "accountWithFallbackPermitted";
            //@ts-ignore
            let newOrder = yield SalesForcer.createNewOrder(newOrderObj, "new", "bulk", "Local FedEx");
            expect(newOrder.details.id).to.equal("aNewBulkOrder3Created");
            expect(newOrder.details.fulfillment.shippingService).to.equal("Local FedEx");
            expect(newOrder.details.fulfillment.inventoryId).to.be.equal("aGoodFallbackInventory");
            expect(newOrder.details.orderDetails.orderType).to.equal("Order - From Bulk");
            expect(newOrder.details.notes).to.equal("Order specified bulk inventory inventoryReplacementOnly which was not available or valid\nAssigned order to inventory ID aGoodFallbackInventory");
        }));
        it('Creates a new order from bulk stock but target not specified - Target is local so override shipping', () => __awaiter(void 0, void 0, void 0, function* () {
            let newOrderObj = orderObject.createNew();
            newOrderObj.details.locationId = "locationFour";
            newOrderObj.details.externalOrderNumber = "anOrderWithoutInventoryIdSpecified";
            newOrderObj.details.orderDetails.bd2Model = "Standard";
            newOrderObj.details.fulfillment.qtyRequested = 25;
            newOrderObj.details.money.moneyCurrency = "USD";
            newOrderObj.details.fulfillment.inventoryId = null;
            newOrderObj.details.accountId = "accountWithFallbackPermitted";
            //@ts-ignore
            let newOrder = yield SalesForcer.createNewOrder(newOrderObj, "new", "bulk", "Priority");
            expect(newOrder.details.id).to.equal("aNewBulkOrder4Created");
            expect(newOrder.details.fulfillment.shippingService).to.equal("Local FedEx");
            expect(newOrder.details.fulfillment.inventoryId).to.be.equal("aGoodFallbackInventory");
            expect(newOrder.details.orderDetails.orderType).to.equal("Order - From Bulk");
            expect(newOrder.details.notes).to.equal("Assigned order to inventory ID aGoodFallbackInventory");
        }));
        it('Creates a new order from bulk stock but target not specified and none available - falls back to RSL', () => __awaiter(void 0, void 0, void 0, function* () {
            let newOrderObj = orderObject.createNew();
            newOrderObj.details.locationId = "locationFive";
            newOrderObj.details.externalOrderNumber = "anOrderWithoutInvIdRSLFallback";
            newOrderObj.details.orderDetails.bd2Model = "Standard";
            newOrderObj.details.fulfillment.qtyRequested = 5;
            newOrderObj.details.money.moneyCurrency = "USD";
            newOrderObj.details.fulfillment.inventoryId = null;
            newOrderObj.details.accountId = "accountWithFallbackPermitted";
            //@ts-ignore
            let newOrder = yield SalesForcer.createNewOrder(newOrderObj, "new", "bulk", "Express");
            expect(newOrder.details.id).to.equal("aNewBulkOrder5Created");
            expect(newOrder.details.fulfillment.shippingService).to.equal("Express");
            expect(newOrder.details.fulfillment.inventoryId).to.be.null;
            expect(newOrder.details.orderDetails.orderType).to.equal("Order - Invoiced");
            expect(newOrder.details.notes).to.equal("Original request was bulk with no target inventory set - fallback to RSL");
        }));
        it('Creates a new order from bulk stock but target not specified and fallback not permitted', () => __awaiter(void 0, void 0, void 0, function* () {
            let newOrderObj = orderObject.createNew();
            newOrderObj.details.locationId = "locationTwo";
            newOrderObj.details.externalOrderNumber = "aNewBulkFallbackOrder";
            newOrderObj.details.orderDetails.bd2Model = "Standard";
            newOrderObj.details.fulfillment.qtyRequested = 5;
            newOrderObj.details.money.moneyCurrency = "USD";
            newOrderObj.details.fulfillment.inventoryId = null;
            newOrderObj.details.accountId = "accountWithFallbackDisabled";
            yield expect(SalesForcer.createNewOrder(newOrderObj, "new", "bulk", "Express")).to.be.rejectedWith("Unable to assign inventory for order aNewBulkFallbackOrder - order was not created");
        }));
        it('Creates a replacement without source specified - bulk is available and chosen automatically - bulk inventory has no external SKU so override shipping option', () => __awaiter(void 0, void 0, void 0, function* () {
            let newOrderObj = orderObject.createNew();
            newOrderObj.details.locationId = "locationSix";
            newOrderObj.details.externalOrderNumber = "aReplacementWithoutSourceAutoSelect";
            newOrderObj.details.orderDetails.bd2Model = "Standard";
            newOrderObj.details.fulfillment.qtyRequested = 25;
            newOrderObj.details.money.moneyCurrency = "USD";
            newOrderObj.details.fulfillment.inventoryId = null;
            newOrderObj.details.accountId = "accountWithFallbackDisabled";
            //@ts-ignore
            let newOrder = yield SalesForcer.createNewOrder(newOrderObj, "replacement", "bulk", "Priority");
            expect(newOrder.details.id).to.equal("aNewBulkReplacement1Created");
            expect(newOrder.details.fulfillment.shippingService).to.equal("Local FedEx");
            expect(newOrder.details.fulfillment.inventoryId).to.be.equal("inventoryReplacementOnly");
            expect(newOrder.details.orderDetails.orderType).to.equal("Replacement - From Bulk");
            expect(newOrder.details.notes).to.equal("Assigned order to inventory ID inventoryReplacementOnly");
        }));
        it('Creates a replacement with source specified but no bulk available - fall back to RSL despite parent fallback setting disabled', () => __awaiter(void 0, void 0, void 0, function* () {
            let newOrderObj = orderObject.createNew();
            newOrderObj.details.locationId = "locationSeven";
            newOrderObj.details.externalOrderNumber = "aReplacementWithoutSourceNoFBAvailable";
            newOrderObj.details.orderDetails.bd2Model = "Standard";
            newOrderObj.details.fulfillment.qtyRequested = 5;
            newOrderObj.details.money.moneyCurrency = "USD";
            newOrderObj.details.fulfillment.inventoryId = null;
            newOrderObj.details.accountId = "accountWithFallbackDisabled";
            //@ts-ignore
            let newOrder = yield SalesForcer.createNewOrder(newOrderObj, "replacement", "bulk", "Local FedEx");
            expect(newOrder.details.id).to.equal("aNewBulkReplacement2Created");
            expect(newOrder.details.fulfillment.shippingService).to.equal("Standard");
            expect(newOrder.details.fulfillment.inventoryId).to.be.null;
            expect(newOrder.details.orderDetails.orderType).to.equal("Replacement");
            expect(newOrder.details.notes).to.equal("Original request was bulk with no target inventory set - fallback to RSL");
        }));
        it('Creates a replacement with source specified but no bulk available (qty) - fall back to different bulk supply', () => __awaiter(void 0, void 0, void 0, function* () {
            let newOrderObj = orderObject.createNew();
            newOrderObj.details.locationId = "locationEight";
            newOrderObj.details.externalOrderNumber = "aReplacementWhatFallsBackToDifferentBulkInventory";
            newOrderObj.details.orderDetails.bd2Model = "Standard";
            newOrderObj.details.fulfillment.qtyRequested = 25;
            newOrderObj.details.money.moneyCurrency = "USD";
            newOrderObj.details.fulfillment.inventoryId = "inventoryMatchesInsufficientQty";
            newOrderObj.details.accountId = "accountWithFallbackDisabled";
            //@ts-ignore
            let newOrder = yield SalesForcer.createNewOrder(newOrderObj, "replacement", "bulk", "Local FedEx");
            expect(newOrder.details.id).to.equal("aNewBulkReplacement3Created");
            expect(newOrder.details.fulfillment.shippingService).to.equal("Local FedEx");
            expect(newOrder.details.fulfillment.inventoryId).to.be.equal("inventoryReplacementOnly");
            expect(newOrder.details.orderDetails.orderType).to.equal("Replacement - From Bulk");
            expect(newOrder.details.notes).to.equal(`Order specified bulk inventory inventoryMatchesInsufficientQty which was not available or valid\nAssigned order to inventory ID inventoryReplacementOnly`);
        }));
    }));
    context('Creating orders from normal RSL/Local stock', () => __awaiter(void 0, void 0, void 0, function* () {
        let newOrderObj = orderObject.createNew();
        before(() => __awaiter(void 0, void 0, void 0, function* () {
            fetchMock.restore();
            fetchMock.post(/./i, (url, opts) => __awaiter(void 0, void 0, void 0, function* () {
                return testCases.checkWriteBody(url, opts);
            }));
            fetchMock.patch(/./i, (url, opts) => __awaiter(void 0, void 0, void 0, function* () {
                return testCases.checkWriteBody(url, opts);
            }));
            fetchMock.get(testCases.accountWithNoSKUs.url, testCases.accountWithNoSKUs.body);
            fetchMock.get(testCases.accountWithFallbackPermitted.url, testCases.accountWithFallbackPermitted.body);
            fetchMock.get(testCases.inventoryMatchesAndPermitsNew.url, testCases.inventoryMatchesAndPermitsNew.body);
            fetchMock.get(testCases.inventoryMatchesInsufficientQty.url, testCases.inventoryMatchesInsufficientQty.body);
            fetchMock.get(testCases.fallBackInventoryNoMatch.url, testCases.fallBackInventoryNoMatch.body);
            fetchMock.get(testCases.accountWithFallbackDisabled.url, testCases.accountWithFallbackDisabled.body);
            fetchMock.get(testCases.inventoryReplacementOnly.url, testCases.inventoryReplacementOnly.body);
            fetchMock.get(testCases.fallBackInventoryWithMatchWithoutExtSKU.url, testCases.fallBackInventoryWithMatchWithoutExtSKU.body);
            fetchMock.get(testCases.fallBackInventoryReplacementNoMatch.url, testCases.fallBackInventoryReplacementNoMatch.body);
            newOrderObj.details.locationId = "someId";
            newOrderObj.details.externalOrderNumber = "aNewOrderWithoutInvoiceStatus";
            newOrderObj.details.orderDetails.bd2Model = "Standard";
            newOrderObj.details.fulfillment.qtyRequested = 1;
            newOrderObj.details.accountId = "someAccountId";
            newOrderObj.details.fulfillment.inventoryId = "somethingThatSHouldNotBeHere";
        }));
        it('Throws an exception if the order is new and the money fields dont add up', () => __awaiter(void 0, void 0, void 0, function* () {
            newOrderObj.details.money.moneyTotal = 999;
            yield expect(SalesForcer.createNewOrder(newOrderObj, "new", "default", "Local FedEx")).to.be.rejectedWith('Transaction currency required');
            newOrderObj.details.money.moneyTotal = null;
            newOrderObj.details.money.moneyCurrency = "USD";
            yield expect(SalesForcer.createNewOrder(newOrderObj, "new", "default", "Local FedEx")).to.be.rejectedWith('New orders must have a grand total');
            newOrderObj.details.money.moneyTotal = 999;
            newOrderObj.details.fulfillment.qtyRequested = 3;
            newOrderObj.details.money.moneyUnitCost = 333.0;
            newOrderObj.details.money.moneyTax = 20;
            yield expect(SalesForcer.createNewOrder(newOrderObj, "new", "default", "Local FedEx")).to.be.rejectedWith('Grand total was $999 but should have been $1019');
        }));
        it('Removes bulk inventory ID for non-bulk orders, also sets invoice status as Not Sent unless otherwise stated for all new orders - Also test manual adjustments y not', () => __awaiter(void 0, void 0, void 0, function* () {
            newOrderObj.details.money.moneyManualAdjustments = -20;
            //@ts-ignore
            let newOrder = yield SalesForcer.createNewOrder(newOrderObj, "new", "default", "Local FedEx");
            expect(newOrder.details.id).to.equal("goodNewNoInvStatus");
            expect(newOrder.details.fulfillment.shippingService).to.equal("Local FedEx");
            expect(newOrder.details.fulfillment.inventoryId).to.be.null;
            expect(newOrder.details.invoicing.invoiceStatus).to.equal("Not Sent");
            expect(newOrder.details.orderDetails.orderType).to.equal("Order - Invoiced");
            //@ts-ignore
            newOrderObj.details.id = null;
            newOrderObj.loadedFromSF = false;
            newOrderObj.details.externalOrderNumber = "aNewOrderWithInvoiceStatus";
            newOrderObj.details.invoicing.invoiceStatus = "Sent";
            //@ts-ignore
            let newOrderWithInvoice = yield SalesForcer.createNewOrder(newOrderObj, "new", "default", "Local FedEx");
            expect(newOrderWithInvoice.details.id).to.equal("goodNewInvStatus");
            expect(newOrderWithInvoice.details.invoicing.invoiceStatus).to.equal("Sent");
        }));
        it.skip('Logs an error but doesnt throw exception if from Shopify and money doesnt add up | leave this for now - want to make the logger module have an optional slack notification field', () => __awaiter(void 0, void 0, void 0, function* () {
        }));
        it('Always sets invoice status as NA for replacement orders - also money zeroed out', () => __awaiter(void 0, void 0, void 0, function* () {
            //@ts-ignore
            newOrderObj.details.id = null;
            newOrderObj.loadedFromSF = false;
            newOrderObj.details.externalOrderNumber = "aReplacementOverridingInvoiceStatus";
            //@ts-ignore
            newOrderObj.details.invoicing.invoiceStatus = null;
            //@ts-ignore
            let newReplacementOrder = yield SalesForcer.createNewOrder(newOrderObj, "replacement", "default", "Standard");
            expect(newReplacementOrder.details.id).to.equal("goodOverriddenStatus");
            expect(newReplacementOrder.details.invoicing.invoiceStatus).to.equal("NA");
            expect(newReplacementOrder.details.money.moneyManualAdjustments).to.be.equal(0);
            expect(newReplacementOrder.details.money.moneyShipping).to.equal(0);
            expect(newReplacementOrder.details.money.moneyTax).to.be.equal(0);
            expect(newReplacementOrder.details.money.moneyTotal).to.equal(0);
            expect(newReplacementOrder.details.money.moneyUnitCost).to.be.equal(0);
        }));
    }));
    context('Creating sample orders', () => __awaiter(void 0, void 0, void 0, function* () {
        let newOrderObj = orderObject.createNew();
        before(() => __awaiter(void 0, void 0, void 0, function* () {
            fetchMock.restore();
            fetchMock.post(/./i, (url, opts) => __awaiter(void 0, void 0, void 0, function* () {
                return testCases.checkWriteBody(url, opts);
            }));
            fetchMock.patch(/./i, (url, opts) => __awaiter(void 0, void 0, void 0, function* () {
                return testCases.checkWriteBody(url, opts);
            }));
            fetchMock.get(testCases.accountWithNoSKUs.url, testCases.accountWithNoSKUs.body);
            newOrderObj.details.locationId = "someId";
            newOrderObj.details.externalOrderNumber = "aNewOrderWithoutInvoiceStatus";
            newOrderObj.details.orderDetails.bd2Model = "Standard";
            newOrderObj.details.fulfillment.qtyRequested = 10;
            newOrderObj.details.accountId = "someAccountId";
            newOrderObj.details.money.moneyCurrency = "USD";
            newOrderObj.details.fulfillment.inventoryId = "somethingThatSHouldNotBeHere";
        }));
        it('Throws an exception if qty = 0 (not sample specific but this section is a bit barren)', () => __awaiter(void 0, void 0, void 0, function* () {
            newOrderObj.details.fulfillment.qtyRequested = 0;
            yield expect(SalesForcer.createNewOrder(newOrderObj, "sample", "default", "Standard")).to.be.rejectedWith("Invalid Quantity 0");
        }));
        it('Throws an exception creating shipped order without deets (same)', () => __awaiter(void 0, void 0, void 0, function* () {
            newOrderObj.details.fulfillment.qtyRequested = 1;
            newOrderObj.details.fulfillment.orderStatus = "Shipped";
            yield expect(SalesForcer.createNewOrder(newOrderObj, "sample", "default", "Standard")).to.be.rejectedWith("Orders require tracking to be created in the shipped or partially shipped state");
            newOrderObj.details.fulfillment.orderStatus = "Partially Shipped";
            yield expect(SalesForcer.createNewOrder(newOrderObj, "sample", "default", "Standard")).to.be.rejectedWith("Orders require tracking to be created in the shipped or partially shipped state");
            newOrderObj.details.fulfillment.shippingTrackingCarrier = "Some Carrier";
            yield expect(SalesForcer.createNewOrder(newOrderObj, "sample", "default", "Standard")).to.be.rejectedWith("Orders require tracking to be created in the shipped or partially shipped state");
            newOrderObj.details.fulfillment.shippingTrackingCarrier = "";
            newOrderObj.details.fulfillment.shippingTrackingNumber = "123456789";
            yield expect(SalesForcer.createNewOrder(newOrderObj, "sample", "default", "Standard")).to.be.rejectedWith("Orders require tracking to be created in the shipped or partially shipped state");
        }));
        it('Creates an order thats already shipped (same) + null money amounts and invoice set to NA', () => __awaiter(void 0, void 0, void 0, function* () {
            newOrderObj.details.fulfillment.orderStatus = "Shipped";
            newOrderObj.details.fulfillment.shippingTrackingCarrier = "Some Carrier";
            newOrderObj.details.fulfillment.shippingTrackingNumber = "123456789";
            newOrderObj.details.externalOrderNumber = "aShippedOrder";
            //@ts-ignore
            newOrderObj.details.invoicing.invoiceStatus = null;
            //@ts-ignore
            let newSample = yield SalesForcer.createNewOrder(newOrderObj, "sample", "default", "Standard");
            expect(newSample.details.fulfillment.orderStatus).to.equal("Shipped");
            expect(newSample.details.id).to.equal("aPreShippedOrder");
            expect(newSample.details.invoicing.invoiceStatus).to.equal("NA");
        }));
        it('Creates a paused order (same) + invoice status overridden to NA', () => __awaiter(void 0, void 0, void 0, function* () {
            //@ts-ignore
            newOrderObj.details.id = null;
            newOrderObj.loadedFromSF = false;
            newOrderObj.details.fulfillment.orderStatus = "Paused";
            newOrderObj.details.fulfillment.shippingTrackingCarrier = null;
            newOrderObj.details.fulfillment.shippingTrackingNumber = null;
            newOrderObj.details.externalOrderNumber = "aPausedOrder";
            newOrderObj.details.fulfillment.shippingService = null;
            //@ts-ignore
            let newSample = yield SalesForcer.createNewOrder(newOrderObj, "sample", "default", "Priority");
            expect(newSample.details.id).to.equal("aPrePausedOrder");
            expect(newSample.details.invoicing.invoiceStatus).to.equal("NA");
        }));
    }));
    context('Updating order statuses', () => __awaiter(void 0, void 0, void 0, function* () {
        let theOrder;
        before(() => __awaiter(void 0, void 0, void 0, function* () {
            fetchMock.reset();
            fetchMock.patch(/./i, (url, opts) => __awaiter(void 0, void 0, void 0, function* () {
                return testCases.checkOrderPatch(url, opts);
            }));
            fetchMock.get(testCases.anOrderToUpdate.url, testCases.anOrderToUpdate.body);
        }));
        it('Pauses an order (and adds a note)', () => __awaiter(void 0, void 0, void 0, function* () {
            theOrder = yield SalesForcer.getBD2Orders({ id: 'anOrderToUpdate' });
            theOrder = theOrder[0];
            theOrder.details.fulfillment.orderStatus = "Partially Shipped";
            yield expect(theOrder.pauseOrder()).to.be.rejectedWith(`Method is only valid for orders in state: Ordered`);
            theOrder.details.fulfillment.orderStatus = "Ordered";
            let pauseReq = yield theOrder.pauseOrder();
            expect(pauseReq).to.be.true;
            expect(theOrder.details.notes).to.include('Order set to Paused');
            expect(theOrder.details.fulfillment.orderStatus).to.equal('Paused');
        }));
        it('Resumes an order (and adds a note)', () => __awaiter(void 0, void 0, void 0, function* () {
            theOrder = theOrder;
            theOrder.details.fulfillment.orderStatus = "Ordered";
            yield expect(theOrder.resumeOrder()).to.be.rejectedWith(`Method is only valid for orders in state: Paused`);
            theOrder.details.fulfillment.orderStatus = "Paused";
            let resumeReq = yield theOrder.resumeOrder();
            expect(resumeReq).to.be.true;
            expect(theOrder.details.notes).to.include('Order set to Paused');
            expect(theOrder.details.notes).to.include('Order set to Ordered');
            expect(theOrder.details.fulfillment.orderStatus).to.equal('Ordered');
        }));
        it('Marks an ordered as being fulfilled', () => __awaiter(void 0, void 0, void 0, function* () {
            theOrder = theOrder;
            theOrder.details.fulfillment.orderStatus = "Shipped";
            yield expect(theOrder.markFulfilled()).to.be.rejectedWith(`Method is only valid for orders in state: Paused | Ordered`);
            theOrder.details.fulfillment.orderStatus = "Paused";
            let fullReq = yield theOrder.markFulfilled();
            expect(fullReq).to.be.true;
            expect(theOrder.details.notes).to.include('Order set to Paused');
            expect(theOrder.details.notes).to.include('Order set to Ordered');
            expect(theOrder.details.notes).to.include('Order set to Fulfilling');
            expect(theOrder.details.fulfillment.orderStatus).to.equal('Fulfilling');
        }));
        it('Cancels an order (and adds a note)', () => __awaiter(void 0, void 0, void 0, function* () {
            theOrder = theOrder;
            theOrder.details.fulfillment.orderStatus = "Shipped";
            yield expect(theOrder.cancelOrder()).to.be.rejectedWith(`Method is only valid for orders in state: Paused | Ordered`);
            theOrder.details.fulfillment.orderStatus = "Ordered";
            let cancelReq = yield theOrder.cancelOrder();
            expect(cancelReq).to.be.true;
            expect(theOrder.details.notes).to.include('Order set to Paused');
            expect(theOrder.details.notes).to.include('Order set to Ordered');
            expect(theOrder.details.notes).to.include('Order set to Fulfilling');
            expect(theOrder.details.notes).to.include('Order set to Cancelled');
            expect(theOrder.details.fulfillment.orderStatus).to.equal('Cancelled');
        }));
        it('Adds tracking', () => __awaiter(void 0, void 0, void 0, function* () {
            theOrder = theOrder;
            yield expect(theOrder.addTracking("FedEx", "123456789")).to.be.rejectedWith(`Method is only valid for orders in state: Paused | Ordered | Partially Shipped | Fulfilling`);
            theOrder.details.fulfillment.orderStatus = "Ordered";
            yield expect(theOrder.addTracking("")).to.be.rejectedWith("Tracking carrier and number required");
            let trackingReq = yield theOrder.addTracking("FedEx", "123456789", 3);
            expect(trackingReq).to.be.true;
            expect(theOrder.details.notes).to.include('Added tracking for FedEx 123456789 - Qty: 3');
            expect(theOrder.details.fulfillment.orderStatus).to.equal('Partially Shipped');
            expect(theOrder.details.fulfillment.qtyFulfilled).to.equal(3);
            yield expect(theOrder.addTracking("USPS", "555", 3)).to.be.rejectedWith("Currently all shipments must use same carrier");
            yield theOrder.addTracking("FedEx", "987654321", 4);
            expect(theOrder.details.notes).to.include('Added tracking for FedEx 987654321 - Qty: 4');
            expect(theOrder.details.fulfillment.orderStatus).to.equal('Partially Shipped');
            expect(theOrder.details.fulfillment.qtyFulfilled).to.equal(7);
            yield expect(theOrder.addTracking("FedEx", "555", 4)).to.be.rejectedWith("Attempted to ship 11 units when requested is only 10");
            yield theOrder.addTracking("FedEx", "QQQQQQ", 3);
            expect(theOrder.details.fulfillment.orderStatus).to.equal('Shipped');
            expect(theOrder.details.fulfillment.qtyFulfilled).to.equal(10);
            expect(theOrder.details.notes).to.include('Order set to Shipped');
            expect(theOrder.details.notes).to.include('Order set to Paused');
            expect(theOrder.details.notes).to.include('Order set to Ordered');
            expect(theOrder.details.notes).to.include('Order set to Fulfilling');
            expect(theOrder.details.notes).to.include('Order set to Cancelled');
            expect(theOrder.details.notes).to.include('Added tracking for FedEx 123456789 - Qty: 3');
            expect(theOrder.details.notes).to.include('Added tracking for FedEx 987654321 - Qty: 4');
            expect(theOrder.details.notes).to.include('Added tracking for FedEx QQQQQQ - Qty: 3');
            expect(theOrder.details.fulfillment.shippingTrackingNumber).to.include("123456789");
            expect(theOrder.details.fulfillment.shippingTrackingNumber).to.include("987654321");
            expect(theOrder.details.fulfillment.shippingTrackingNumber).to.include("QQQQQQ");
        }));
        it('Forces mark shipped after partial fulfillment', () => __awaiter(void 0, void 0, void 0, function* () {
            theOrder = theOrder;
            yield expect(theOrder.markShipped()).to.be.rejectedWith("Method is only valid for orders in state: Paused | Ordered | Partially Shipped | Fulfilling");
            theOrder.details.fulfillment.orderStatus = "Partially Shipped";
            yield expect(theOrder.markShipped()).to.be.rejectedWith("Final shipment qty is a required field");
            yield expect(theOrder.markShipped(25)).to.be.rejectedWith("Attempted to mark shipped with 25 units when requested is only 10");
            let forceReq = yield theOrder.markShipped(5);
            expect(forceReq).to.be.true;
            expect(theOrder.details.fulfillment.qtyFulfilled).to.equal(5);
            expect(theOrder.details.notes).to.include(`Forced status to shipped`);
        }));
    }));
}));
