var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import chai from 'chai';
import chaiAsPromised from "chai-as-promised";
import fetchMock from 'fetch-mock';
import * as testAccountCases from './testDetails/salesforce.cases.accounts.js';
import * as testAuthCases from './testDetails/salesforce.cases.auth.js';
import * as testInventoryCases from './testDetails/salesforce.cases.inventory.js';
import * as SalesForcer from '../salesforce.js';
import * as SfAPI from '../salesforceAPI.js';
const expect = chai.expect;
chai.use(chaiAsPromised);
describe('Test the SalesForcer module', () => __awaiter(void 0, void 0, void 0, function* () {
    before(() => __awaiter(void 0, void 0, void 0, function* () {
        SfAPI.disconnect();
        fetchMock.restore();
        let authMock = testAuthCases.apiMockCases.goodTokenReq;
        fetchMock.post(authMock.req.url, { status: authMock.req.code, body: authMock.req.body });
        yield SfAPI.connect();
        fetchMock.restore();
    }));
    // Note: No update/create methods for inventory
    context('Test pre-canned inventory functions', () => __awaiter(void 0, void 0, void 0, function* () {
        before(() => __awaiter(void 0, void 0, void 0, function* () {
            fetchMock.restore();
            fetchMock.get(testInventoryCases.noInventory.req.url, testInventoryCases.noInventory.req.body);
            fetchMock.get(testInventoryCases.nonUniqueInvById.req.url, testInventoryCases.nonUniqueInvById.req.body);
            fetchMock.get(testInventoryCases.inventoryById.req.url, testInventoryCases.inventoryById.req.body);
            fetchMock.get(testAccountCases.accountByNameOrIDWithLocations.req.url, testAccountCases.accountByNameOrIDWithLocations.req.body);
            fetchMock.get(testAccountCases.getAccountNoMatch.req.url, testAccountCases.getAccountNoMatch.req.body);
            fetchMock.get(testInventoryCases.multipleInventoryByAccountWithFilters.req.url, testInventoryCases.multipleInventoryByAccountWithFilters.req.body);
            fetchMock.get(testInventoryCases.multipleInventoryByAccountWithoutFilters.req.url, testInventoryCases.multipleInventoryByAccountWithoutFilters.req.body);
        }));
        it('Searching by name/id - validates inputs', () => __awaiter(void 0, void 0, void 0, function* () {
            //@ts-ignore
            yield expect(SalesForcer.getBD2Inventories({ yert: "asdadas" })).to.be.rejectedWith(`Unsupported filter yert for query type Bulk_BD2_Order__c`);
        }));
        it('Searching by name/id - returns null for not found', () => __awaiter(void 0, void 0, void 0, function* () {
            let noResults = yield SalesForcer.getBD2Inventories({ id: "NoResults" });
            expect(noResults).to.be.empty;
        }));
        it('Returns an inventory by name', () => __awaiter(void 0, void 0, void 0, function* () {
            let resultsByName = yield SalesForcer.getBD2Inventories({ inventoryName: "aResultByName" });
            expect(resultsByName[0].details).to.deep.equal(testInventoryCases.inventoryById.resp);
        }));
        it('Returns an inventory by ID', () => __awaiter(void 0, void 0, void 0, function* () {
            let resultsById = yield SalesForcer.getBD2Inventories({ id: "aResultById" });
            expect(resultsById[0].details).to.deep.equal(testInventoryCases.inventoryById.resp);
        }));
        it('Searching by account - returns empty array', () => __awaiter(void 0, void 0, void 0, function* () {
            const noInvParent = yield SalesForcer.getBD2Accounts({ id: "someRandomIdLookATthis0mg" });
            const noInvs = yield noInvParent[0].getInventory({ shopifyVariantId: 'omgwtfbbq' });
            expect(noInvs).to.be.empty;
        }));
        it('Returns all inventories by account', () => __awaiter(void 0, void 0, void 0, function* () {
            const invParent = yield SalesForcer.getBD2Accounts({ id: "someRandomIdLookATthis0mg" });
            const invs = yield invParent[0].getInventory();
            expect(invs.map((a) => (a.details))).to.deep.equal(testInventoryCases.multipleInventoryByAccountWithoutFilters.resp);
        }));
        it('Returns inventories for accounts with filters', () => __awaiter(void 0, void 0, void 0, function* () {
            const invParent = yield SalesForcer.getBD2Accounts({ id: "someRandomIdLookATthis0mg" });
            const invs = yield invParent[0].getInventory({ isInventoryAvailable: true, inventoryType: "New", qtyAvailable: ">10" });
            expect(invs.map((a) => (a.details))).to.deep.equal(testInventoryCases.multipleInventoryByAccountWithFilters.resp);
        }));
    }));
}));
