var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
//@ts-nocheck
import chai from 'chai';
import chaiAsPromised from "chai-as-promised";
import * as dotenv from 'dotenv';
import * as SalesForcer from '../salesforce.js';
const expect = chai.expect;
chai.use(chaiAsPromised);
dotenv.config();
const isProduction = (process.env.NODE_ENV === "PRODUCTION");
const testSfAccountId = 'a0gJA0000000Zm0YAE';
describe('Run actual live SF server tests', () => __awaiter(void 0, void 0, void 0, function* () {
    let testAccount = null;
    let testLocation = null;
    let smallReplacementFromBulk;
    context('Get test account', () => __awaiter(void 0, void 0, void 0, function* () {
        it('Retrieves the test account', () => __awaiter(void 0, void 0, void 0, function* () {
            let testAccountReq = yield SalesForcer.getBD2Accounts({ accountName: 'API Test Account' });
            expect(testAccountReq.length).to.equal(1);
            testAccount = testAccountReq[0];
            expect(testAccount.details.id).to.equal(testSfAccountId);
        }));
        it('Gets all child locations', () => __awaiter(void 0, void 0, void 0, function* () {
            let locations = yield testAccount.getLocations();
            expect(locations, 'All child locations must be deleted for testing').to.be.empty;
        }));
    }));
    context('Create a new location', () => __awaiter(void 0, void 0, void 0, function* () {
        let newLocationDeets = null;
        let newLocation = null;
        let checkLocation = null;
        it('Creates a new child location', () => __awaiter(void 0, void 0, void 0, function* () {
            newLocationDeets = testAccount.createLocation();
            newLocationDeets.details = {
                locationName: 'test location 1',
                businessName: '',
                accountId: testSfAccountId,
                email: 'location@email.com',
                phone: null,
                dealerId: "dealer123",
                address: {
                    receiverName: "Christopher John Nevin",
                    streetAddress: "56 Brodie St",
                    city: "Mount. Pearl",
                    province: "NL",
                    postalCode: "A1N0B5",
                    country: "CA",
                    fullAddress: ''
                }
            };
            newLocation = yield SalesForcer.createOrFindLocation(newLocationDeets);
        }));
        it('Gets the new location back', () => __awaiter(void 0, void 0, void 0, function* () {
            const roughFilters = { streetAddress: '56Brodie Street' };
            checkLocation = yield testAccount.getLocations(roughFilters, false);
            expect(checkLocation).to.be.empty;
            checkLocation = yield testAccount.getLocations(roughFilters, true);
            expect(checkLocation).to.have.lengthOf(1);
            checkLocation = checkLocation[0];
            expect(checkLocation.details.address.streetAddress).to.equal("56 Brodie St");
            expect(checkLocation.details.address.postalCode).to.equal("A1N 0B5");
        }));
        it('Updates the location to add a phone number but not change email address', () => __awaiter(void 0, void 0, void 0, function* () {
            const testPhone = "7091239876";
            // expect(checkLocation.details.phone).to.be.null PUT ME BACK
            checkLocation.details.phone = testPhone;
            let updateLocation = yield SalesForcer.createOrFindLocation(checkLocation);
            expect(updateLocation.details.id).to.equal(checkLocation.details.id);
            let checkPhoneUpdate = yield testAccount.getLocations({ id: updateLocation.details.id });
            expect(checkPhoneUpdate).to.have.lengthOf(1);
            expect(checkPhoneUpdate[0].details.phone).to.equal(testPhone);
            testLocation = checkPhoneUpdate[0];
        }));
    }));
    context('Creating Orders', () => __awaiter(void 0, void 0, void 0, function* () {
        let newRSLOrder;
        let newBulkOrder;
        it('Creates a new paused order for RSL from Shopify - default shipping service, default invoice status', () => __awaiter(void 0, void 0, void 0, function* () {
            newRSLOrder = testLocation.createOrder(5);
            newRSLOrder.details.externalOrderNumber = "APausedOrder";
            newRSLOrder.details.fulfillment.orderStatus = "Paused";
            newRSLOrder.details.orderDetails.overrideName = "Joe Exotic";
            newRSLOrder.details.orderDetails.dealerId = "123456";
            newRSLOrder.details.money.moneyUnitCost = 149.99;
            newRSLOrder.details.money.moneyShipping = 25;
            newRSLOrder.details.money.moneyTotal = 25 + 149.99 * 5;
            newRSLOrder = yield SalesForcer.createNewOrder(newRSLOrder, "new", "default", "Standard", true);
            let newOrderCheck = yield SalesForcer.getBD2Orders({ id: newRSLOrder.details.id });
            expect(newOrderCheck).to.have.lengthOf(1);
            expect(newOrderCheck[0].details.id).to.not.be.null.and.not.be.empty;
            expect(newOrderCheck[0].details.accountId).to.equal('a0gJA0000000Zm0'); // Not 100% sure why it returns the old version
            expect(newOrderCheck[0].details.locationId).to.equal(newRSLOrder.details.locationId);
            expect(newOrderCheck[0].details.fulfillment.qtyRequested).to.equal(5);
            expect(!!newOrderCheck[0].details.internalOrderNumber.match(/^BD2-\d+?$/)).to.be.true;
            expect(newOrderCheck[0].details.externalOrderNumber).to.equal("APausedOrder");
            expect(newOrderCheck[0].details.invoicing.invoiceStatus).to.equal("Shopify");
            expect(newOrderCheck[0].details.fulfillment.orderStatus).to.equal("Paused");
            expect(newOrderCheck[0].details.fulfillment.shippingService).to.equal("Standard");
        }));
        it('Creates a new order from bulk - no inventory specified', () => __awaiter(void 0, void 0, void 0, function* () {
            newBulkOrder = testLocation.createOrder(8);
            newBulkOrder.details.externalOrderNumber = "ABulkOrder";
            newBulkOrder.details.orderDetails.overrideEmail = "some@dude.com";
            newBulkOrder = yield SalesForcer.createNewOrder(newBulkOrder, "new", "bulk", "Local FedEx", false);
            let bulkCheck = yield SalesForcer.getBD2Orders({ id: newBulkOrder.details.id });
            expect(bulkCheck).to.have.lengthOf(1);
            expect(bulkCheck[0].details.fulfillment.inventoryId).to.include('a0fJA000000RUeZ');
            expect(bulkCheck[0].details.fulfillment.shippingService).to.equal("Standard");
            expect(bulkCheck[0].details.orderDetails.overrideEmail).to.equal("some@dude.com");
            expect(bulkCheck[0].details.invoicing.invoiceStatus).to.equal("NA");
            let targetInventory = yield SalesForcer.getBD2Inventories({ id: bulkCheck[0].details.fulfillment.inventoryId });
            expect(targetInventory).to.have.lengthOf(1);
            expect(targetInventory[0].details.qty.qtyAvailable).to.equal(2);
            yield expect(SalesForcer.createNewOrder(newBulkOrder, "new", "bulk", "Priority", false)).to.be.rejectedWith(`Unable to assign inventory for order ABulkOrder - order was not created`);
        }));
        it('Creates a new bulk order from shopify', () => __awaiter(void 0, void 0, void 0, function* () {
            let bulkShopOrder = testLocation.createOrder(2);
            bulkShopOrder.details.externalOrderNumber = "aBulkShopifyOrder";
            bulkShopOrder.details.fulfillment.inventoryId = "a0fJA000000RUeZ";
            bulkShopOrder = yield SalesForcer.createNewOrder(bulkShopOrder, "new", "bulk", "Priority", true);
            let rslCheck = yield SalesForcer.getBD2Orders({ id: bulkShopOrder.details.id });
            expect(rslCheck).to.have.lengthOf(1);
            expect(rslCheck[0].details.fulfillment.shippingService).to.equal("Priority");
            expect(rslCheck[0].details.orderDetails.orderType).to.equal("Order - From Bulk");
            expect(rslCheck[0].details.externalOrderNumber).to.equal("aBulkShopifyOrder");
            expect(rslCheck[0].details.fulfillment.inventoryId).to.include('a0fJA000000RUeZ');
            expect(rslCheck[0].details.invoicing.invoiceStatus).to.equal("NA");
        }));
        it('Creates a new order for RSL to be invoiced', () => __awaiter(void 0, void 0, void 0, function* () {
            let invoicedRSLOrder = testLocation.createOrder(5);
            invoicedRSLOrder.details.externalOrderNumber = "anInvoicedRSLOrder";
            invoicedRSLOrder.details.money.moneyShipping = 20;
            invoicedRSLOrder.details.money.moneyTotal = 20;
            invoicedRSLOrder = yield SalesForcer.createNewOrder(invoicedRSLOrder, "new", "default", "Priority", false);
            let rslCheck = yield SalesForcer.getBD2Orders({ id: invoicedRSLOrder.details.id });
            expect(rslCheck).to.have.lengthOf(1);
            expect(rslCheck[0].details.fulfillment.shippingService).to.equal("Priority");
            expect(rslCheck[0].details.orderDetails.orderType).to.equal("Order - Invoiced");
            expect(rslCheck[0].details.externalOrderNumber).to.equal("anInvoicedRSLOrder");
            expect(rslCheck[0].details.fulfillment.inventoryId).to.be.null;
            expect(rslCheck[0].details.money.moneyCurrency).to.equal("CAD");
            expect(rslCheck[0].details.invoicing.invoiceStatus).to.equal("Not Sent");
        }));
        it('Creates a replacement order from bulk - overrides shippingmethod', () => __awaiter(void 0, void 0, void 0, function* () {
            smallReplacementFromBulk = testLocation.createOrder(2);
            smallReplacementFromBulk.details.externalOrderNumber = "aSmallReplacementOrder";
            smallReplacementFromBulk = yield SalesForcer.createNewOrder(smallReplacementFromBulk, "replacement", "bulk", "Priority", false);
            let bulkCheck = yield SalesForcer.getBD2Orders({ id: smallReplacementFromBulk.details.id });
            expect(bulkCheck).to.have.lengthOf(1);
            expect(bulkCheck[0].details.externalOrderNumber).to.equal("aSmallReplacementOrder");
            expect(bulkCheck[0].details.fulfillment.shippingService).to.equal("Local FedEx");
            expect(bulkCheck[0].details.fulfillment.inventoryId).to.include("a0fJA000000RUee");
            expect(bulkCheck[0].details.orderDetails.orderType).to.equal("Replacement - From Bulk");
            expect(bulkCheck[0].details.invoicing.invoiceStatus).to.equal("NA");
            let targetInventory = yield SalesForcer.getBD2Inventories({ id: bulkCheck[0].details.fulfillment.inventoryId });
            expect(targetInventory).to.have.lengthOf(1);
            expect(targetInventory[0].details.qty.qtyAvailable).to.equal(3);
        }));
        it('Creates a replacement from bulk - falls back to RSL', () => __awaiter(void 0, void 0, void 0, function* () {
            let bigReplacementFromBulk = testLocation.createOrder(10);
            bigReplacementFromBulk.details.externalOrderNumber = "aFallbackReplacementOrder";
            bigReplacementFromBulk = yield SalesForcer.createNewOrder(bigReplacementFromBulk, "replacement", "bulk", "Priority", false);
            let bulkCheck = yield SalesForcer.getBD2Orders({ id: bigReplacementFromBulk.details.id });
            expect(bulkCheck).to.have.lengthOf(1);
            expect(bulkCheck[0].details.externalOrderNumber).to.equal("aFallbackReplacementOrder");
            expect(bulkCheck[0].details.fulfillment.shippingService).to.equal("Priority");
            expect(bulkCheck[0].details.fulfillment.inventoryId).to.be.null;
            expect(bulkCheck[0].details.orderDetails.orderType).to.equal("Replacement");
            expect(bulkCheck[0].details.invoicing.invoiceStatus).to.equal("NA");
        }));
        it('Creates a sample that has already been shipped via FedEx w/ tracking 123456789', () => __awaiter(void 0, void 0, void 0, function* () {
            let sampleOrder = testLocation.createOrder(3);
            sampleOrder.details.externalOrderNumber = 'aSampleOrder';
            sampleOrder.details.fulfillment.shippingTrackingCarrier = "Fedex";
            sampleOrder.details.fulfillment.shippingTrackingNumber = "123456789";
            sampleOrder.details.fulfillment.orderStatus = "Shipped";
            sampleOrder = yield SalesForcer.createNewOrder(sampleOrder, "sample", "default", "Standard", false);
            let checkSample = yield SalesForcer.getBD2Orders({ id: sampleOrder.details.id });
            expect(checkSample).to.have.lengthOf(1);
            expect(checkSample[0].details.invoicing.invoiceStatus).to.equal("NA");
            expect(checkSample[0].details.externalOrderNumber).to.equal("aSampleOrder");
            expect(checkSample[0].details.fulfillment.orderStatus).to.equal("Shipped");
            expect(checkSample[0].details.fulfillment.shippingTrackingCarrier).to.equal("Fedex");
            expect(checkSample[0].details.fulfillment.shippingTrackingNumber).to.equal("123456789");
        }));
    }));
    // update to change order status on bulk rder and check that qty avail changes too
    context('Updating Orders', () => __awaiter(void 0, void 0, void 0, function* () {
        let newOrderToUpdate;
        before(() => __awaiter(void 0, void 0, void 0, function* () {
            newOrderToUpdate = testLocation.createOrder(10);
            newOrderToUpdate.details.externalOrderNumber = "anOrderToUpdate";
            newOrderToUpdate.details.money.moneyTotal = 10;
            newOrderToUpdate.details.money.moneyUnitCost = 1;
            newOrderToUpdate = yield SalesForcer.createNewOrder(newOrderToUpdate, "new", "default", "Priority", false);
        }));
        it('Pauses an order', () => __awaiter(void 0, void 0, void 0, function* () {
            yield newOrderToUpdate.pauseOrder();
            let check = yield SalesForcer.getBD2Orders({ id: newOrderToUpdate.details.id });
            expect(check[0].details.fulfillment.orderStatus).to.equal("Paused");
        }));
        it('Then resumes it', () => __awaiter(void 0, void 0, void 0, function* () {
            yield newOrderToUpdate.resumeOrder();
            let check = yield SalesForcer.getBD2Orders({ id: newOrderToUpdate.details.id });
            expect(check[0].details.fulfillment.orderStatus).to.equal("Ordered");
        }));
        it('Then marks it as being fulfilled', () => __awaiter(void 0, void 0, void 0, function* () {
            yield newOrderToUpdate.markFulfilled();
            let check = yield SalesForcer.getBD2Orders({ id: newOrderToUpdate.details.id });
            expect(check[0].details.fulfillment.orderStatus).to.equal("Fulfilling");
        }));
        it('Then adds tracking', () => __awaiter(void 0, void 0, void 0, function* () {
            yield newOrderToUpdate.addTracking("FedEx", "987654321", 4);
            let check = yield SalesForcer.getBD2Orders({ id: newOrderToUpdate.details.id });
            expect(check[0].details.fulfillment.shippingTrackingNumber).to.equal("987654321");
            expect(check[0].details.fulfillment.shippingTrackingCarrier).to.equal("FedEx");
            expect(check[0].details.fulfillment.orderStatus).to.equal("Partially Shipped");
            yield newOrderToUpdate.addTracking("FedEx", "OMGWTFBBQ", 6);
            check = yield SalesForcer.getBD2Orders({ id: newOrderToUpdate.details.id });
            expect(check[0].details.fulfillment.shippingTrackingNumber).to.equal("987654321\nOMGWTFBBQ");
            expect(check[0].details.fulfillment.shippingTrackingCarrier).to.equal("FedEx");
            expect(check[0].details.fulfillment.orderStatus).to.equal("Shipped");
            expect(check[0].details.notes).to.include('Order set to Paused');
            expect(check[0].details.notes).to.include('Order set to Ordered');
            expect(check[0].details.notes).to.include('Order set to Fulfilling');
            expect(check[0].details.notes).to.include('Order set to Shipped');
            expect(check[0].details.notes).to.include('Added tracking for FedEx 987654321');
            expect(check[0].details.notes).to.include('Added tracking for FedEx OMGWTFBBQ');
        }));
        it('Forces another order to shipped state - then checks to make sure the bulk is now using qty sent not requested', () => __awaiter(void 0, void 0, void 0, function* () {
            let targetInventory = yield SalesForcer.getBD2Inventories({ id: smallReplacementFromBulk.details.fulfillment.inventoryId });
            expect(targetInventory).to.have.lengthOf(1);
            expect(targetInventory[0].details.qty.qtyAvailable).to.equal(3);
            yield smallReplacementFromBulk.markShipped(1);
            let check = yield SalesForcer.getBD2Orders({ id: smallReplacementFromBulk.details.id });
            expect(check[0].details.fulfillment.orderStatus).to.equal("Shipped");
            expect(check[0].details.notes).to.include('Forced status to shipped');
            targetInventory = yield SalesForcer.getBD2Inventories({ id: check[0].details.fulfillment.inventoryId });
            expect(targetInventory).to.have.lengthOf(1);
            expect(targetInventory[0].details.qty.qtyAvailable).to.equal(4);
        }));
    }));
}));
