export const duplicateLocationTests = [
    {
        testing: 'Validates multiple addresses with same first number + inconsistent CA postal code spacing also street vs st',
        matchURL: `WHERE City__c LIKE '%Mount%Pearl%' AND Province__c LIKE 'NL%' AND Country__c = 'CA' AND Postal_Code__c LIKE 'A1N%0B5' AND Street_Address__c LIKE '%56%' AND BD2_Account__c = 'someGoodOlParentId'`.replace(/%/g, "%25").replace(/ /g, "%20").replace(/'/g, "%27"),
        requestDeets: {
            streetAddress: "#56 Brodie Street",
            city: "Mount Pearl",
            province: "NL",
            postalCode: "A1N 0B5",
            country: "CA",
            accountId: "someGoodOlParentId"
        },
        returnBody: {
            "totalSize": 2,
            "done": true,
            "records": [
                {
                    "attributes": {
                        "type": "BD2_Location__c",
                        "url": "/services/data/v57.0/sobjects/BD2_Location__c/a0hJA0000004bKFYAY"
                    },
                    "Id": "1",
                    "BD2_Account__c": "someGoodOlParentId",
                    "Name": "theWrongLocation",
                    "Business_Name__c": null,
                    "Dealer_ID__c": null,
                    "Receiver_Name__c": "Some otherdude",
                    "Street_Address__c": "56 Yert Street",
                    "City__c": "Mount Pearl",
                    "Province__c": "NL",
                    "Postal_Code__c": "A1N 0B5",
                    "Country__c": "CA",
                    "Phone_Number__c": null,
                    "Receiver_Email_Address__c": null,
                    "Shipping_Address__c": null,
                    "CreatedDate": "2023-06-02T12:42:51.000+0000"
                },
                {
                    "attributes": {
                        "type": "BD2_Location__c",
                        "url": "/services/data/v57.0/sobjects/BD2_Location__c/a0hJA0000004bKFYAY"
                    },
                    "Id": "2",
                    "BD2_Account__c": "someGoodOlParentId",
                    "Name": "theRightLocation",
                    "Business_Name__c": null,
                    "Dealer_ID__c": null,
                    "Receiver_Name__c": "Chris Nevin",
                    "Street_Address__c": "56 Brodie St",
                    "City__c": "Mount Pearl",
                    "Province__c": "NL",
                    "Postal_Code__c": "A1N0B5",
                    "Country__c": "CA",
                    "Phone_Number__c": null,
                    "Receiver_Email_Address__c": null,
                    "Shipping_Address__c": null,
                    "CreatedDate": "2023-06-02T12:42:51.000+0000"
                }
            ]
        },
        expectedValue: {
            id: "2",
            locationName: "theRightLocation",
            businessName: null,
            accountId: "someGoodOlParentId",
            email: null,
            phone: null,
            dealerId: null,
            address: {
                receiverName: "Chris Nevin",
                streetAddress: "56 Brodie St",
                city: "Mount Pearl",
                province: "NL",
                postalCode: "A1N0B5",
                country: "CA",
                fullAddress: null
            }
        }
    },
    {
        testing: 'Possible match returned but it has a suite # and the old one didnt - Create new, also remove the dot from city name',
        matchURL: `WHERE City__c LIKE '%Mount%Cityburg%' AND Province__c LIKE 'CT%' AND Country__c = 'CA' AND Postal_Code__c LIKE 'A0A%3F3' AND Street_Address__c LIKE '180%' AND BD2_Account__c = 'nopeSheDontExist'`.replace(/%/g, "%25").replace(/ /g, "%20").replace(/'/g, "%27"),
        requestDeets: {
            streetAddress: "180 Street Place",
            city: "Mount. Cityburg",
            province: "CT",
            postalCode: "A0A3F3",
            country: "CA",
            accountId: "nopeSheDontExist"
        },
        returnBody: {
            "totalSize": 1,
            "done": true,
            "records": [
                {
                    "attributes": {
                        "type": "BD2_Location__c",
                        "url": "/services/data/v57.0/sobjects/BD2_Location__c/a0hJA0000004bKFYAY"
                    },
                    "Id": "3",
                    "BD2_Account__c": "nopeSheDontExist",
                    "Name": "thisAintIt",
                    "Business_Name__c": null,
                    "Dealer_ID__c": null,
                    "Receiver_Name__c": "Some otherdude",
                    "Street_Address__c": "180 Street Place Suite A",
                    "City__c": "Mount Cityburg",
                    "Province__c": "CT",
                    "Postal_Code__c": "A0A 3F3",
                    "Country__c": "US",
                    "Phone_Number__c": null,
                    "Receiver_Email_Address__c": null,
                    "Shipping_Address__c": null,
                    "CreatedDate": "2023-06-02T12:42:51.000+0000"
                }
            ]
        },
        expectedValue: {
            id: "qQqQqQqQq",
            locationName: "Blah blah blah",
            businessName: null,
            accountId: "nopeSheDontExist",
            email: null,
            phone: null,
            dealerId: null,
            address: {
                receiverName: null,
                streetAddress: "180 Street Place",
                city: "Mount Cityburg",
                province: "CT",
                postalCode: "A0A 3F3",
                country: "CA",
                fullAddress: null
            }
        }
    },
    {
        testing: 'Appartment spelled differently',
        matchURL: `WHERE City__c LIKE '%Mount%Cityburg%' AND Province__c LIKE 'CT%' AND Country__c = 'US' AND Postal_Code__c LIKE '%90210%' AND Street_Address__c LIKE '180%' AND BD2_Account__c = 'anAccount'`.replace(/%/g, "%25").replace(/ /g, "%20").replace(/'/g, "%27"),
        requestDeets: {
            streetAddress: "180 Street Place Apt #81A",
            city: "Mount Cityburg",
            province: "CT",
            postalCode: "90210",
            country: "US",
            accountId: "anAccount"
        },
        returnBody: {
            "totalSize": 1,
            "done": true,
            "records": [
                {
                    "attributes": {
                        "type": "BD2_Location__c",
                        "url": "/services/data/v57.0/sobjects/BD2_Location__c/a0hJA0000004bKFYAY"
                    },
                    "Id": "4",
                    "BD2_Account__c": "anAccount",
                    "Name": "thisOneGood",
                    "Business_Name__c": null,
                    "Dealer_ID__c": null,
                    "Receiver_Name__c": "Person X",
                    "Street_Address__c": "180 Street Place Appartment 81A",
                    "City__c": "Mount Cityburg",
                    "Province__c": "CT",
                    "Postal_Code__c": "90210",
                    "Country__c": "US",
                    "Phone_Number__c": null,
                    "Receiver_Email_Address__c": "thing@yert.com",
                    "Shipping_Address__c": null,
                    "CreatedDate": "2023-06-02T12:42:51.000+0000"
                }
            ]
        },
        expectedValue: {
            id: "4",
            locationName: "thisOneGood",
            businessName: null,
            accountId: "anAccount",
            email: "thing@yert.com",
            phone: null,
            dealerId: null,
            address: {
                receiverName: "Person X",
                streetAddress: "180 Street Place Appartment 81A",
                city: "Mount Cityburg",
                province: "CT",
                postalCode: "90210",
                country: "US",
                fullAddress: null
            }
        }
    },
    {
        testing: 'New address has extended zip code and old one doesnt + Dots in names + Compass Directions',
        matchURL: `WHERE City__c LIKE '%St%John%s%' AND Province__c LIKE 'NY%' AND Country__c = 'US' AND Postal_Code__c LIKE '%12345%' AND Street_Address__c LIKE '142-12%' AND BD2_Account__c = 'anotherAccount'`.replace(/%/g, "%25").replace(/ /g, "%20").replace(/'/g, "%27"),
        requestDeets: {
            streetAddress: "142-12 Northrop AVE Nw",
            city: "St. John's",
            province: "NY",
            postalCode: "12345-5432",
            country: "US",
            accountId: "anotherAccount"
        },
        returnBody: {
            "totalSize": 1,
            "done": true,
            "records": [
                {
                    "attributes": {
                        "type": "BD2_Location__c",
                        "url": "/services/data/v57.0/sobjects/BD2_Location__c/a0hJA0000004bKFYAY"
                    },
                    "Id": "5",
                    "BD2_Account__c": "anotherAccount",
                    "Name": "hello",
                    "Business_Name__c": "howAreYou",
                    "Dealer_ID__c": "5Q",
                    "Receiver_Name__c": "Person Y",
                    "Street_Address__c": "142-12 Northrop avenue NorthW",
                    "City__c": "St Johns",
                    "Province__c": "NY",
                    "Postal_Code__c": "12345",
                    "Country__c": "US",
                    "Phone_Number__c": null,
                    "Receiver_Email_Address__c": "stuff@email.com",
                    "Shipping_Address__c": null,
                    "CreatedDate": "2023-06-02T12:42:51.000+0000"
                }
            ]
        },
        expectedValue: {
            id: "5",
            locationName: "hello",
            businessName: "howAreYou",
            accountId: "anotherAccount",
            email: "stuff@email.com",
            phone: null,
            dealerId: "5Q",
            address: {
                receiverName: "Person Y",
                streetAddress: "142-12 Northrop avenue NorthW",
                city: "St Johns",
                province: "NY",
                postalCode: "12345",
                country: "US",
                fullAddress: null
            }
        }
    }
];
export const addressMatchingCases = [
    {
        "parent": {
            "street": "123 Main Street NW Apartment 45",
            "city": "Washington",
            "provState": "DC",
            "postalCode": "20001",
            "country": "USA"
        },
        "variants": [
            {
                "street": "#123 Main Street N.W. Apartment #45",
                "city": "Washington",
                "provState": "DC",
                "postalCode": "20001",
                "country": "USA"
            },
            {
                "street": "123 Main St. Northwest Apartment 45",
                "city": "Washington",
                "provState": "DC",
                "postalCode": "20001",
                "country": "USA"
            },
            {
                "street": "123 Main Street NW Apt. 45",
                "city": "Wash-ington",
                "provState": "DC",
                "postalCode": "20001",
                "country": "USA"
            },
            {
                "street": "att: John Doe, 123 Main Street NW Apartment 45",
                "city": "Washington",
                "provState": "DC",
                "postalCode": "20001",
                "country": "USA"
            },
            {
                "street": "TechCorp, 123 Main Street NW Apartment 45",
                "city": "Washington",
                "provState": "DC",
                "postalCode": "20001-1234",
                "country": "USA"
            }
        ]
    },
    {
        "parent": {
            "street": "456 Elm Street",
            "city": "Toronto",
            "provState": "ON",
            "postalCode": "M4B 1B3",
            "country": "Canada"
        },
        "variants": [
            {
                "street": "456 Elm St.",
                "city": "Toronto",
                "provState": "ON",
                "postalCode": "M4B1B3",
                "country": "Canada"
            },
            {
                "street": "456 Elm St",
                "city": "To-ronto",
                "provState": "ON",
                "postalCode": "M4B 1B3",
                "country": "Canada"
            },
            {
                "street": "att: Jane Doe, 456 Elm St",
                "city": "Toronto",
                "provState": "ON",
                "postalCode": "M4B1B3",
                "country": "Canada"
            },
            {
                "street": "456 Elm Street",
                "city": "Toronto",
                "provState": "ON",
                "postalCode": "M4B 1B3",
                "country": "Canada"
            },
            {
                "street": "456 Elm St.",
                "city": "Toronto",
                "provState": "ON",
                "postalCode": "M4B1B3",
                "country": "Canada"
            }
        ]
    },
    {
        "parent": {
            "street": "789 South Pine Street Building B-2",
            "city": "San Francisco",
            "provState": "CA",
            "postalCode": "94107",
            "country": "USA"
        },
        "variants": [
            {
                "street": "789 South Pine St. Bldg B-2",
                "city": "San Francisco",
                "provState": "CA",
                "postalCode": "94107",
                "country": "USA"
            },
            {
                "street": "att: Alice Smith, 789 S. Pine St Building B-2",
                "city": "San Francisco",
                "provState": "CA",
                "postalCode": "94107-1234",
                "country": "USA"
            },
            {
                "street": "789 S. Pine Street Bldg. B-2",
                "city": "San Francisco",
                "provState": "CA",
                "postalCode": "94107",
                "country": "USA"
            },
            {
                "street": "789 South Pine Street Building B-2",
                "city": "San-Francisco",
                "provState": "CA",
                "postalCode": "94107",
                "country": "USA"
            },
            {
                "street": "789 S. Pine St. Building B-2",
                "city": "San Francisco",
                "provState": "CA",
                "postalCode": "94107",
                "country": "USA"
            }
        ]
    },
    {
        "parent": {
            "street": "2468 N Maple Street Apartment 100-B",
            "city": "Chicago",
            "provState": "IL",
            "postalCode": "60614",
            "country": "USA"
        },
        "variants": [
            {
                "street": "att: Robert Johnson, 2468 N. Maple St. Apt. 100-B",
                "city": "Chi-cago",
                "provState": "IL",
                "postalCode": "60614",
                "country": "USA"
            },
            {
                "street": "#2468 North Maple St Apartment 100-B",
                "city": "Chicago",
                "provState": "IL",
                "postalCode": "60614",
                "country": "USA"
            },
            {
                "street": "2468 N. Maple St Apartment #100-B",
                "city": "Chicago",
                "provState": "IL",
                "postalCode": "60614-1234",
                "country": "USA"
            },
            {
                "street": "2468 N Maple St. Apartment 100B",
                "city": "Chicago",
                "provState": "IL",
                "postalCode": "60614",
                "country": "USA"
            },
            {
                "street": "TechHub, 2468 N Maple St Apartment 100-B",
                "city": "Chicago",
                "provState": "IL",
                "postalCode": "60614",
                "country": "USA"
            }
        ]
    },
    {
        "parent": {
            "street": "1515 West 21st Street South Unit 305",
            "city": "Vancouver",
            "provState": "BC",
            "postalCode": "V5Z 2J1",
            "country": "Canada"
        },
        "variants": [
            {
                "street": "1515 W. 21st St. S. Unit 305",
                "city": "Vancouver",
                "provState": "BC",
                "postalCode": "V5Z2J1",
                "country": "Canada"
            },
            {
                "street": "1515 W 21st Street S Unit #305",
                "city": "Van-couver",
                "provState": "BC",
                "postalCode": "V5Z 2J1",
                "country": "Canada"
            },
            {
                "street": "1515 West 21st St. South Unit 305",
                "city": "Vancouver",
                "provState": "BC",
                "postalCode": "V5Z 2J1",
                "country": "Canada"
            },
            {
                "street": "1515 West 21st Street S Unit 305",
                "city": "Vancouver",
                "provState": "BC",
                "postalCode": "V5Z2J1",
                "country": "Canada"
            },
            {
                "street": "att: Michael Lee, 1515 West 21st Street S Unit 305",
                "city": "Vancouver",
                "provState": "BC",
                "postalCode": "V5Z 2J1",
                "country": "Canada"
            }
        ]
    },
    {
        "parent": {
            "street": "100 East Washington Avenue",
            "city": "Madison",
            "provState": "WI",
            "postalCode": "53703",
            "country": "USA"
        },
        "variants": [
            {
                "street": "100 E Washington Ave",
                "city": "Madison",
                "provState": "WI",
                "postalCode": "53703",
                "country": "USA"
            },
            {
                "street": "100 E. Washington Avenue",
                "city": "Madi-son",
                "provState": "WI",
                "postalCode": "53703",
                "country": "USA"
            },
            {
                "street": "100 East Washington Av",
                "city": "Madison",
                "provState": "WI",
                "postalCode": "53703",
                "country": "USA"
            },
            {
                "street": "100 E Washington Avenue",
                "city": "Madison",
                "provState": "WI",
                "postalCode": "53703-1234",
                "country": "USA"
            },
            {
                "street": "Tech Center, 100 E. Washington Avenue",
                "city": "Madison",
                "provState": "WI",
                "postalCode": "53703",
                "country": "USA"
            }
        ]
    },
    {
        "parent": {
            "street": "32 Atlantic Street SW Unit 4A",
            "city": "Washington",
            "provState": "DC",
            "postalCode": "20032",
            "country": "USA"
        },
        "variants": [
            {
                "street": "32 Atlantic St SW Unit #4A",
                "city": "Washington",
                "provState": "DC",
                "postalCode": "20032-1234",
                "country": "USA"
            },
            {
                "street": "32 Atlantic Street S.W. Unit 4-A",
                "city": "Washington",
                "provState": "DC",
                "postalCode": "20032",
                "country": "USA"
            },
            {
                "street": "32 Atlantic Street SW Unit 4A",
                "city": "Washington",
                "provState": "DC",
                "postalCode": "20032",
                "country": "USA"
            },
            {
                "street": "att: Sarah Miller, 32 Atlantic Street SW Unit 4A",
                "city": "Washington",
                "provState": "DC",
                "postalCode": "20032",
                "country": "USA"
            },
            {
                "street": "32 Atlantic St. S.W. Unit 4A",
                "city": "Washington",
                "provState": "DC",
                "postalCode": "20032",
                "country": "USA"
            }
        ]
    },
    {
        "parent": {
            "street": "2180 Main Street NW Building A-5",
            "city": "Atlanta",
            "provState": "GA",
            "postalCode": "30344",
            "country": "USA"
        },
        "variants": [
            {
                "street": "2180 Main St NW Bldg A-5",
                "city": "Atlanta",
                "provState": "GA",
                "postalCode": "30344-1234",
                "country": "USA"
            },
            {
                "street": "2180 Main St. NW Building A-5",
                "city": "Atlanta",
                "provState": "GA",
                "postalCode": "30344",
                "country": "USA"
            },
            {
                "street": "2180 Main St NW Bldg. A-5",
                "city": "Atlanta",
                "provState": "GA",
                "postalCode": "30344",
                "country": "USA"
            },
            {
                "street": "2180 Main St. N.W. Building A-5",
                "city": "Atlan-ta",
                "provState": "GA",
                "postalCode": "30344",
                "country": "USA"
            },
            {
                "street": "Tech Plaza, 2180 Main St. N.W. Building A-5",
                "city": "Atlanta",
                "provState": "GA",
                "postalCode": "30344",
                "country": "USA"
            }
        ]
    },
    {
        "parent": {
            "street": "1500 N Maple Road Apartment 205",
            "city": "Ann Arbor",
            "provState": "MI",
            "postalCode": "48103",
            "country": "USA"
        },
        "variants": [
            {
                "street": "1500 North Maple Rd Apt 205",
                "city": "Ann Arbor",
                "provState": "MI",
                "postalCode": "48103-1234",
                "country": "USA"
            },
            {
                "street": "1500 N Maple Road Apt. 205",
                "city": "Ann Arbor",
                "provState": "MI",
                "postalCode": "48103",
                "country": "USA"
            },
            {
                "street": "1500 N Maple Rd Apartment 205",
                "city": "Ann Arbor",
                "provState": "MI",
                "postalCode": "48103",
                "country": "USA"
            },
            {
                "street": "att: John Doe, 1500 N Maple Road Apt 205",
                "city": "Ann Arbor",
                "provState": "MI",
                "postalCode": "48103",
                "country": "USA"
            },
            {
                "street": "1500 N. Maple Rd. Apartment #205",
                "city": "Ann Arbor",
                "provState": "MI",
                "postalCode": "48103",
                "country": "USA"
            }
        ]
    },
    {
        "parent": {
            "street": "4200 W 70th Street",
            "city": "Prairie Village",
            "provState": "KS",
            "postalCode": "66208",
            "country": "USA"
        },
        "variants": [
            {
                "street": "4200 West 70th St",
                "city": "Prairie Village",
                "provState": "KS",
                "postalCode": "66208-1234",
                "country": "USA"
            },
            {
                "street": "4200 W. 70th Street",
                "city": "Prairie Village",
                "provState": "KS",
                "postalCode": "66208",
                "country": "USA"
            },
            {
                "street": "4200 W 70th St",
                "city": "Prairie Village",
                "provState": "KS",
                "postalCode": "66208",
                "country": "USA"
            },
            {
                "street": "4200 West 70th Street",
                "city": "Prairie Village",
                "provState": "KS",
                "postalCode": "66208",
                "country": "USA"
            },
            {
                "street": "Happy Family Market, 4200 West 70th Street",
                "city": "Prairie Village",
                "provState": "KS",
                "postalCode": "66208",
                "country": "USA"
            }
        ]
    },
    {
        "parent": {
            "street": "52 2nd Avenue North Unit #202",
            "city": "Columbus",
            "provState": "MT",
            "postalCode": "59019",
            "country": "USA"
        },
        "variants": [
            {
                "street": "52 2nd Ave N Unit 202",
                "city": "Columbus",
                "provState": "MT",
                "postalCode": "59019",
                "country": "USA"
            },
            {
                "street": "#52 2nd Avenue North Unit 202",
                "city": "Columbus",
                "provState": "MT",
                "postalCode": "59019-1234",
                "country": "USA"
            },
            {
                "street": "52 2nd Avenue N. Unit #202",
                "city": "Columbus",
                "provState": "MT",
                "postalCode": "59019",
                "country": "USA"
            },
            {
                "street": "52 2nd Ave North Unit 202",
                "city": "Columbus",
                "provState": "MT",
                "postalCode": "59019",
                "country": "USA"
            },
            {
                "street": "attn: Jane Doe, #52 2nd Avenue N Unit #202",
                "city": "Columbus",
                "provState": "MT",
                "postalCode": "59019",
                "country": "USA"
            }
        ]
    },
    {
        "parent": {
            "street": "123 S Elm Street Building B-104",
            "city": "Denver",
            "provState": "CO",
            "postalCode": "80246",
            "country": "USA"
        },
        "variants": [
            {
                "street": "123 South Elm St Bldg B-104",
                "city": "Denver",
                "provState": "CO",
                "postalCode": "80246-1234",
                "country": "USA"
            },
            {
                "street": "123 S Elm St Building B-104",
                "city": "Denver",
                "provState": "CO",
                "postalCode": "80246",
                "country": "USA"
            },
            {
                "street": "123 S. Elm St. Bldg. B-104",
                "city": "Denver",
                "provState": "CO",
                "postalCode": "80246",
                "country": "USA"
            },
            {
                "street": "TechCorp, 123 S Elm Street Building B-104",
                "city": "Denver",
                "provState": "CO",
                "postalCode": "80246",
                "country": "USA"
            },
            {
                "street": "123 S Elm Street Building B-104",
                "city": "Den-ver",
                "provState": "CO",
                "postalCode": "80246",
                "country": "USA"
            }
        ]
    },
    {
        "parent": {
            "street": "645 Queen Street West Apartment 3B",
            "city": "Toronto",
            "provState": "ON",
            "postalCode": "M5V 2B7",
            "country": "Canada"
        },
        "variants": [
            {
                "street": "645 Queen St W Apt 3B",
                "city": "Toronto",
                "provState": "ON",
                "postalCode": "M5V2B7",
                "country": "Canada"
            },
            {
                "street": "645 Queen Street W. Apartment #3B",
                "city": "Toronto",
                "provState": "ON",
                "postalCode": "M5V 2B7",
                "country": "Canada"
            },
            {
                "street": "attn: Sarah Johnson, 645 Queen St. West Apartment 3B",
                "city": "Toronto",
                "provState": "ON",
                "postalCode": "M5V 2B7",
                "country": "Canada"
            },
            {
                "street": "645 Queen St West Apartment 3B",
                "city": "Toronto",
                "provState": "ON",
                "postalCode": "M5V2B7",
                "country": "Canada"
            },
            {
                "street": "645 Queen Street W Apartment 3-B",
                "city": "Toronto",
                "provState": "ON",
                "postalCode": "M5V 2B7",
                "country": "Canada"
            }
        ]
    },
    {
        "parent": {
            "street": "74-4925 Riverside Drive East Floor 6",
            "city": "Windsor",
            "provState": "ON",
            "postalCode": "N8Y 5B5",
            "country": "Canada"
        },
        "variants": [
            {
                "street": "74-4925 Riverside Dr E Fl 6",
                "city": "Windsor",
                "provState": "ON",
                "postalCode": "N8Y5B5",
                "country": "Canada"
            },
            {
                "street": "74-4925 Riverside Dr. East Floor #6",
                "city": "Windsor",
                "provState": "ON",
                "postalCode": "N8Y 5B5",
                "country": "Canada"
            },
            {
                "street": "74-4925 Riverside Drive E. Floor 6",
                "city": "Windsor",
                "provState": "ON",
                "postalCode": "N8Y 5B5",
                "country": "Canada"
            },
            {
                "street": "74-4925 Riverside Dr E Floor 6",
                "city": "Wind-sor",
                "provState": "ON",
                "postalCode": "N8Y5B5",
                "country": "Canada"
            },
            {
                "street": "RiverCorp, 74-4925 Riverside Drive East Floor 6",
                "city": "Windsor",
                "provState": "ON",
                "postalCode": "N8Y 5B5",
                "country": "Canada"
            }
        ]
    },
    {
        "parent": {
            "street": "908-50 W Georgia Street Building C",
            "city": "Vancouver",
            "provState": "BC",
            "postalCode": "V6B 1V7",
            "country": "Canada"
        },
        "variants": [
            {
                "street": "908-50 West Georgia St Bldg C",
                "city": "Vancouver",
                "provState": "BC",
                "postalCode": "V6B1V7",
                "country": "Canada"
            },
            {
                "street": "908-50 W Georgia St Bldg. C",
                "city": "Vancouver",
                "provState": "BC",
                "postalCode": "V6B 1V7",
                "country": "Canada"
            },
            {
                "street": "908-50 W. Georgia St. Building C",
                "city": "Van-couver",
                "provState": "BC",
                "postalCode": "V6B 1V7",
                "country": "Canada"
            },
            {
                "street": "908-50 W Georgia Street Bldg C",
                "city": "Vancouver",
                "provState": "BC",
                "postalCode": "V6B1V7",
                "country": "Canada"
            },
            {
                "street": "908-50 West Georgia Street Building C",
                "city": "Vancouver",
                "provState": "BC",
                "postalCode": "V6B 1V7",
                "country": "Canada"
            }
        ]
    },
    {
        "parent": {
            "street": "6559 N Lincoln Avenue Apartment 205",
            "city": "Chicago",
            "provState": "IL",
            "postalCode": "60659",
            "country": "USA"
        },
        "variants": [
            {
                "street": "6559 North Lincoln Ave Apt 205",
                "city": "Chicago",
                "provState": "IL",
                "postalCode": "60659-2201",
                "country": "USA"
            },
            {
                "street": "6559 N Lincoln Ave Apartment #205",
                "city": "Chicago",
                "provState": "IL",
                "postalCode": "60659",
                "country": "USA"
            },
            {
                "street": "att: John Doe, 6559 N. Lincoln Avenue Apartment 205",
                "city": "Chicago",
                "provState": "IL",
                "postalCode": "60659",
                "country": "USA"
            },
            {
                "street": "6559 N Lincoln Avenue Apartment 205",
                "city": "Chi-cago",
                "provState": "IL",
                "postalCode": "60659",
                "country": "USA"
            },
            {
                "street": "6559 N Lincoln Ave. Apt. 205",
                "city": "Chicago",
                "provState": "IL",
                "postalCode": "60659",
                "country": "USA"
            }
        ]
    }
];
