import * as orderCases from './salesforce.cases.orders.js';
import { util } from 'chai';
const locationsWithReturnRecords = [
    {
        "attributes": {
            "type": "BD2_Location__c",
            "url": "/services/data/v57.0/sobjects/BD2_Location__c/a0hJA0000004bKFYAY"
        },
        "Id": "locationWithReturnsId1",
        "BD2_Account__c": "someIdWithKids",
        "Name": "locationWithReturnsName1",
        "Business_Name__c": "Chris' Garage",
        "Dealer_ID__c": "123456",
        "Receiver_Name__c": "Chris Nevin",
        "Street_Address__c": "56 Brodie St",
        "City__c": "Mount Pearl",
        "Province__c": "NL - NEWFOUNDLAND AND LABRADOR",
        "Postal_Code__c": "A1N 0B5",
        "Country__c": "CA",
        "Phone_Number__c": "7097491234",
        "Receiver_Email_Address__c": "thing@stuff.com",
        "Shipping_Address__c": "the full address with<br>linebreaks",
        "CreatedDate": "2023-06-02T12:42:51.000+0000"
    },
    {
        "attributes": {
            "type": "BD2_Location__c",
            "url": "/services/data/v57.0/sobjects/BD2_Location__c/a0hJA0000004bKFYAY"
        },
        "Id": "locationWithReturnsId2",
        "BD2_Account__c": "someIdWithKids",
        "Name": "locationWithReturnsName2",
        "Business_Name__c": "Chris' Garage",
        "Dealer_ID__c": "123456",
        "Receiver_Name__c": "Chris Nevin",
        "Street_Address__c": "56 Brodie St",
        "City__c": "Mount Pearl",
        "Province__c": "NL - NEWFOUNDLAND AND LABRADOR",
        "Postal_Code__c": "A1N 0B5",
        "Country__c": "CA",
        "Phone_Number__c": "7097491234",
        "Receiver_Email_Address__c": "thing@stuff.com",
        "Shipping_Address__c": "the full address with<br>linebreaks",
        "CreatedDate": "2023-06-02T12:42:51.000+0000"
    }
];
export const noLocationsFound = {
    req: {
        url: /DontExist|WHERE%20BD2_Account__c%20=%20%27dinks%27$/,
        code: 200,
        body: {
            "totalSize": 0,
            "done": true,
            "records": []
        }
    },
    resp: []
};
export const locationThatExists = {
    req: {
        url: /WHERE%20Id%20=%20%27ARealIdThatExists%27$|WHERE%20Name%20=%20%27ARealPlaceThatExists%27$|WHERE%20\(BD2_Account__c%20=%20%27someRandomIdLookATthis0mg%27%20OR%20BD2_Account__c%20=%20%27someRandomIdLookATthis%27\)$/,
        code: 200,
        body: {
            "totalSize": 1,
            "done": true,
            "records": [
                {
                    "attributes": {
                        "type": "BD2_Location__c",
                        "url": "/services/data/v57.0/sobjects/BD2_Location__c/a0hJA0000004bKFYAY"
                    },
                    "Id": "ARealIdThatExists",
                    "BD2_Account__c": "someRandomIdLookATthis0mg",
                    "Name": "ARealPlaceThatExists",
                    "Business_Name__c": "Chris' Garage",
                    "Dealer_ID__c": "123456",
                    "Receiver_Name__c": "Chris Nevin",
                    "Street_Address__c": "56 Brodie St",
                    "City__c": "Mount Pearl",
                    "Province__c": "NL - NEWFOUNDLAND AND LABRADOR",
                    "Postal_Code__c": "A1N 0B5",
                    "Country__c": "CA",
                    "Phone_Number__c": "7097491234",
                    "Receiver_Email_Address__c": "thing@stuff.com",
                    "Shipping_Address__c": "the full address with<br>linebreaks",
                    "CreatedDate": "2023-06-02T12:42:51.000+0000"
                }
            ]
        }
    },
    resp: {
        id: "ARealIdThatExists",
        locationName: "ARealPlaceThatExists",
        businessName: "Chris' Garage",
        accountId: "someRandomIdLookATthis0mg",
        email: "thing@stuff.com",
        phone: "7097491234",
        dealerId: "123456",
        address: {
            receiverName: "Chris Nevin",
            streetAddress: "56 Brodie St",
            city: "Mount Pearl",
            province: "NL",
            postalCode: "A1N 0B5",
            country: "CA",
            fullAddress: "the full address with<br>linebreaks"
        }
    },
    orderResp: orderCases.getOrderInternalId.resp,
    noOrderResp: []
};
export const locationsBelongsTosomeIdWithKids = {
    req: {
        url: /WHERE%20BD2_Account__c%20=%20%27someIdWithKids%27$/,
        code: 200,
        body: {
            "totalSize": 2,
            "done": true,
            "records": locationsWithReturnRecords
        }
    },
    resp: [
        {
            id: "locationWithReturnsId1",
            locationName: "locationWithReturnsName1",
            businessName: "Chris' Garage",
            accountId: "someIdWithKids",
            email: "thing@stuff.com",
            phone: "7097491234",
            dealerId: "123456",
            address: {
                receiverName: "Chris Nevin",
                streetAddress: "56 Brodie St",
                city: "Mount Pearl",
                province: "NL",
                postalCode: "A1N 0B5",
                country: "CA",
                fullAddress: "the full address with<br>linebreaks"
            }
        },
        {
            id: "locationWithReturnsId2",
            locationName: "locationWithReturnsName2",
            businessName: "Chris' Garage",
            accountId: "someIdWithKids",
            email: "thing@stuff.com",
            phone: "7097491234",
            dealerId: "123456",
            address: {
                receiverName: "Chris Nevin",
                streetAddress: "56 Brodie St",
                city: "Mount Pearl",
                province: "NL",
                postalCode: "A1N 0B5",
                country: "CA",
                fullAddress: "the full address with<br>linebreaks"
            }
        },
    ]
};
export const locationWithReturnsOne = {
    req: {
        url: /WHERE%20Id%20=%20%27locationWithReturnsId1%27/,
        code: 200,
        body: {
            "totalSize": 1,
            "done": true,
            "records": [locationsWithReturnRecords[0]]
        }
    }
};
export function checkLocationBody(url, opts) {
    if (opts.headers['Content-Type'] !== 'application/json') {
        throw `Any post/patch gotta be application/json`;
    }
    let expectedBody = null;
    let body = JSON.parse(opts.body);
    let respObj = null;
    if (url.match(/__c\/$/)) {
        switch (body.BD2_Account__c) {
            case "accountDoesntExist":
                respObj = createNonExistantAccountId;
                break;
            case "malformedId":
                respObj = createMalformedAccountId;
                break;
            case "duplicateId":
                respObj = createDuplicate;
                break;
            case "missingNameField":
                respObj = createMissingField;
                break;
            case "someRandomIdLookATthis0mg":
                let expectedBody = JSON.stringify({
                    Name: 'Yert',
                    Business_Name__c: null,
                    BD2_Account__c: 'someRandomIdLookATthis0mg',
                    Receiver_Email_Address__c: null,
                    Phone_Number__c: null,
                    Dealer_ID__c: null,
                    Receiver_Name__c: null,
                    Street_Address__c: null,
                    City__c: null,
                    Province__c: 'NY - New York',
                    Postal_Code__c: null,
                    Country__c: null
                });
                if (expectedBody != opts.body) {
                    throw 'wrong body';
                }
                respObj = createSuccess;
                break;
            default:
                throw `wtf @ ${util.inspect(body)}`;
        }
    }
    else {
        if (url.match(/conflictingValue$/i)) {
            expectedBody = { "Business_Name__c": "FFFFF", "Receiver_Email_Address__c": null, "Phone_Number__c": null, "Dealer_ID__c": null, "Receiver_Name__c": null, "Street_Address__c": null, "City__c": null, "Province__c": null, "Postal_Code__c": "12345", "Country__c": null };
            respObj = createDuplicate;
        }
        else if (url.match(/thingToUpdate$/)) {
            expectedBody = { "Business_Name__c": null, "Receiver_Email_Address__c": null, "Phone_Number__c": null, "Dealer_ID__c": null, "Receiver_Name__c": null, "Street_Address__c": null, "City__c": null, "Province__c": null, "Postal_Code__c": "12345", "Country__c": null };
            respObj = updateOk;
        }
        else {
            throw `wtf u at ${url}`;
        }
    }
    if (expectedBody && opts.body !== JSON.stringify(expectedBody)) {
        console.log("\n\nMISMATCH!");
        //@ts-ignore
        for (const [k, v] of Object.entries(expectedBody)) {
            console.log(`${k}: ${v} | ${body[k]} - Mismatch: ${v !== body[k]}`);
        }
        throw `Bad Payload`;
    }
    return { body: respObj.body, status: respObj.code };
}
const updateOk = {
    code: 204,
    body: null
};
const createNonExistantAccountId = {
    code: 400,
    body: [
        {
            "message": "invalid cross reference id",
            "errorCode": "INVALID_CROSS_REFERENCE_KEY",
            "fields": []
        }
    ]
};
const createMalformedAccountId = {
    code: 400,
    body: [
        {
            "message": "Parent Account: id value of incorrect type: ASDAD",
            "errorCode": "MALFORMED_ID",
            "fields": [
                "BD2_Account__c",
            ]
        }
    ]
};
const createDuplicate = {
    code: 400,
    body: [
        {
            "message": "duplicate value found: Name duplicates value on record with id: a0gJA0000000SvBYAU",
            "errorCode": "DUPLICATE_VALUE",
            "fields": []
        }
    ]
};
const createMissingField = {
    code: 400,
    body: [
        {
            "message": "Required fields are missing: [BD2_Account__c ET AL]",
            "errorCode": "REQUIRED_FIELD_MISSING",
            "fields": [
                "BD2_Account__c",
                "Some_Other_Field__c"
            ]
        }
    ]
};
const createSuccess = {
    code: 201,
    body: {
        "id": "newLocationId",
        "success": true,
        "errors": []
    }
};
