const orderFieldsSubstring = `Id, accountID__c, BD2_Location__c, Special_Inventory_Reference__c, Name, BD2_Model__c, Dealer_ID__c, Customer_PO__c, Fulfillment_Date__c, Fulfillment_Reference__c, Invoice_Date__c, Invoice_Number__c, Invoice_Status__c, Currency__c, Invoice_Total__c, Manual_Adjustments__c, Shipping__c, Tax__c, Unit_Cost__c, Notes__c, Order_Status__c, Order_Type__c, Quantity_Fulfilled__c, Quantity_Requested__c, Shipment_Date__c, Shipping_Service__c, Tracking_Carrier__c, Tracking_Number__c, CreatedDate, overrideReceiverName__c, overrideEmail__c`;
const accountFieldsSubstring = `Id, Name, Accounting_Contact_Email__c, Accounting_Contact_Name__c, Accounting_Contact_Phone__c, BD_User_ID__c, Contact_Email__c, Contact_Name__c, Contact_Phone__c, User_Type__c, CreatedDate, Shipping_Email__c, CC_Emails__c, Bundle_SKUs__c, SKUs_to_Bundle__c, Bulk_Fallback_Permitted__c, Mirror_To_Shopify__c, Shopify_Site__c, Test_Account__c`;
const locationFieldsSubstring = `Id, BD2_Account__c, Name, Business_Name__c, Dealer_ID__c, Receiver_Name__c, Street_Address__c, City__c, Province__c, Postal_Code__c, Country__c, Phone_Number__c, Receiver_Email_Address__c, Shipping_Address__c, CreatedDate`;
const inventoryFieldSubstring = `Id, Name, BD2_Account__c, Allow_New__c, Allow_Replacement__c, Available_Quantity__c, Inventory_Available__c, Inventory_Type__c, Shopify_SKU__c, Order_Quantity__c, Quantity_Shipped__c, CreatedDate, RSL_SKU__c`;
const returnFieldSubstring = `Id, Name, Status__c, BD2_Inventory__c, BD2_Location__c, Reference_Number__c, Testing_Link__c, Test_Results__c, Tracking_Number__c, CreatedDate`;
export const queryGeneratorTestCases = {
    order: [
        {
            requiredData: ['id', 'internalOrderNumber', 'moneyTax', 'bd2Model'],
            filters: {
                internalOrderNumber: "internalNumber1",
                orderStatus: "Ordered"
            },
            expected: `q=SELECT Id, Name, Tax__c, BD2_Model__c FROM BD2_Order__c WHERE Name = 'internalNumber1' AND Order_Status__c = 'Ordered'`
        },
        {
            requiredData: ['id', 'internalOrderNumber', 'moneyTax', 'bd2Model'],
            filters: {
                internalOrderNumber: "yert",
                orderStatus: null
            },
            expected: `q=SELECT Id, Name, Tax__c, BD2_Model__c FROM BD2_Order__c WHERE Name = 'yert'`
        },
        {
            requiredData: [],
            filters: {
                internalOrderNumber: "internalNumber5"
            },
            expected: `q=SELECT ${orderFieldsSubstring} FROM BD2_Order__c WHERE Name = 'internalNumber5'`
        },
        {
            requiredData: [],
            filters: {
                externalOrderNumber: "externalOrderNumber2",
                orderStatus: "Fulfilling"
            },
            expected: `q=SELECT ${orderFieldsSubstring} FROM BD2_Order__c WHERE Customer_PO__c = 'externalOrderNumber2' AND Order_Status__c = 'Fulfilling'`
        },
        {
            requiredData: [],
            filters: {
                invoiceNumber: ["3", "9", null],
                orderStatus: "Shipped"
            },
            expected: `q=SELECT ${orderFieldsSubstring} FROM BD2_Order__c WHERE (Invoice_Number__c = '3' OR Invoice_Number__c = '9') AND Order_Status__c = 'Shipped'`
        },
        {
            requiredData: [],
            filters: {
                invoiceNumber: "4"
            },
            expected: `q=SELECT ${orderFieldsSubstring} FROM BD2_Order__c WHERE Invoice_Number__c = '4'`
        },
        {
            requiredData: [],
            filters: {
                invoiceNumber: "4",
                orderStatus: null
            },
            expected: `q=SELECT ${orderFieldsSubstring} FROM BD2_Order__c WHERE Invoice_Number__c = '4'`
        },
        {
            requiredData: [],
            filters: {
                locationId: "someParentLocationId",
                orderStatus: "Fulfilling"
            },
            expected: `q=SELECT ${orderFieldsSubstring} FROM BD2_Order__c WHERE BD2_Location__c = 'someParentLocationId' AND Order_Status__c = 'Fulfilling'`
        }
    ],
    account: [
        {
            requiredData: [],
            filters: {
                accountName: `some dude's shop`,
                type: 'BaaS'
            },
            expected: `q=SELECT ${accountFieldsSubstring} FROM BD2_Account__c WHERE Name = 'some dude\'s shop' AND User_Type__c = 'BaaS'`
        },
        {
            requiredData: [],
            filters: {
                accountName: `a shop/name`
            },
            expected: `q=SELECT ${accountFieldsSubstring} FROM BD2_Account__c WHERE Name = 'a shop/name'`
        },
        {
            requiredData: [],
            filters: {
                type: 'Library'
            },
            expected: `q=SELECT ${accountFieldsSubstring} FROM BD2_Account__c WHERE User_Type__c = 'Library'`
        },
        {
            requiredData: [],
            filters: {},
            expected: `q=SELECT ${accountFieldsSubstring} FROM BD2_Account__c`
        },
        {
            requiredData: [],
            filters: null,
            expected: `q=SELECT ${accountFieldsSubstring} FROM BD2_Account__c`
        },
    ],
    location: [
        {
            requiredData: ['city', 'phone', 'created'],
            filters: {
                accountId: 'someAccountId',
                receiverName: 'Some Dude'
            },
            expected: `q=SELECT City__c, Phone_Number__c, CreatedDate FROM BD2_Location__c WHERE BD2_Account__c = 'someAccountId' AND Receiver_Name__c = 'Some Dude'`
        },
        {
            requiredData: [],
            filters: {
                receiverName: 'Steve',
                locationName: null
            },
            expected: `q=SELECT ${locationFieldsSubstring} FROM BD2_Location__c WHERE Receiver_Name__c = 'Steve'`
        },
        {
            requiredData: [],
            filters: {
                locationName: 'Some Inspection Co',
                streetAddress: '123 FakeStreet'
            },
            expected: `q=SELECT ${locationFieldsSubstring} FROM BD2_Location__c WHERE Name = 'Some Inspection Co' AND Street_Address__c = '123 FakeStreet'`
        },
        {
            requiredData: [],
            filters: {
                businessName: 'inspection co',
                dealerId: '123546'
            },
            expected: `q=SELECT ${locationFieldsSubstring} FROM BD2_Location__c WHERE Business_Name__c = 'inspection co' AND Dealer_ID__c = '123546'`
        },
        {
            requiredData: [],
            filters: {
                email: 'cnevin@yert.ca',
                dealerId: '123546'
            },
            expected: `q=SELECT ${locationFieldsSubstring} FROM BD2_Location__c WHERE Receiver_Email_Address__c = 'cnevin@yert.ca' AND Dealer_ID__c = '123546'`
        },
    ],
    inventory: [
        {
            requiredData: [],
            filters: {
                accountId: 'someParentAccountId',
                allowReplacement: false
            },
            expected: `q=SELECT ${inventoryFieldSubstring} FROM Bulk_BD2_Order__c WHERE BD2_Account__c = 'someParentAccountId' AND Allow_Replacement__c = false`
        },
        {
            requiredData: [],
            filters: {
                isInventoryAvailable: true
            },
            expected: `q=SELECT ${inventoryFieldSubstring} FROM Bulk_BD2_Order__c WHERE Inventory_Available__c = true`
        },
        {
            requiredData: [],
            filters: {
                inventoryName: 'some order ID',
                allowNew: false
            },
            expected: `q=SELECT ${inventoryFieldSubstring} FROM Bulk_BD2_Order__c WHERE Name = 'some order ID' AND Allow_New__c = false`
        },
        {
            requiredData: [],
            filters: {
                inventoryType: 'Refurbished',
                qtyAvailable: 23
            },
            expected: `q=SELECT ${inventoryFieldSubstring} FROM Bulk_BD2_Order__c WHERE Inventory_Type__c = 'Refurbished' AND Available_Quantity__c = '23'`
        },
        {
            requiredData: [],
            filters: {
                shopifyVariantId: 'ABC123'
            },
            expected: `q=SELECT ${inventoryFieldSubstring} FROM Bulk_BD2_Order__c WHERE Shopify_SKU__c = 'ABC123'`
        },
        {
            requiredData: [],
            filters: {
                qtyAvailable: '>5',
                created: '>= 1985-05-21'
            },
            expected: `q=SELECT ${inventoryFieldSubstring} FROM Bulk_BD2_Order__c WHERE Available_Quantity__c > 5 AND CreatedDate >= 1985-05-21T00:00:00Z`
        }
    ],
    return: [
        {
            requiredData: [],
            filters: {
                fate: ['Discarded', 'Stored'],
                inventoryId: '5555555555'
            },
            expected: `q=SELECT ${returnFieldSubstring} FROM BD2_Return__c WHERE (Status__c = 'Discarded' OR Status__c = 'Stored') AND BD2_Inventory__c = '5555555555'`
        },
        {
            requiredData: [],
            filters: {
                referenceNumber: 'abc321',
                locationId: ['666666666666']
            },
            expected: `q=SELECT ${returnFieldSubstring} FROM BD2_Return__c WHERE Reference_Number__c = 'abc321' AND BD2_Location__c = '666666666666'`
        },
        {
            requiredData: [],
            filters: {
                testResults: 'Failed'
            },
            expected: `q=SELECT ${returnFieldSubstring} FROM BD2_Return__c WHERE Test_Results__c = 'Failed'`
        },
        {
            requiredData: [],
            filters: {
                inventoryId: 'LIKE \'%omgbbq%\''
            },
            expected: `q=SELECT ${returnFieldSubstring} FROM BD2_Return__c WHERE BD2_Inventory__c LIKE '%omgbbq%'`
        }
    ]
};
// BUILDING
// 
// BLDG
// 
// FLOOR
// 
// FL
// 
// SUITE
// 
// STE
// 
// UNIT
// 
// UNIT
// 
// ROOM
// 
// RM
// 
// DEPARTMENT
// 
// DEPT
// APPT => APT
